rubric

package
v0.25.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RubricRequestBuilder

type RubricRequestBuilder struct {
	// contains filtered or unexported fields
}

RubricRequestBuilder provides operations to manage the rubric property of the microsoft.graph.educationAssignment entity.

func NewRubricRequestBuilder

NewRubricRequestBuilder instantiates a new RubricRequestBuilder and sets the default values.

func NewRubricRequestBuilderInternal

func NewRubricRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *RubricRequestBuilder

NewRubricRequestBuilderInternal instantiates a new RubricRequestBuilder and sets the default values.

func (*RubricRequestBuilder) CreateDeleteRequestInformation

CreateDeleteRequestInformation delete navigation property rubric for education

func (*RubricRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration added in v0.22.0

CreateDeleteRequestInformationWithRequestConfiguration delete navigation property rubric for education

func (*RubricRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation when set, the grading rubric attached to this assignment.

func (*RubricRequestBuilder) CreateGetRequestInformationWithRequestConfiguration added in v0.22.0

CreateGetRequestInformationWithRequestConfiguration when set, the grading rubric attached to this assignment.

func (*RubricRequestBuilder) CreatePatchRequestInformation

CreatePatchRequestInformation update the navigation property rubric in education

func (*RubricRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration added in v0.22.0

CreatePatchRequestInformationWithRequestConfiguration update the navigation property rubric in education

func (*RubricRequestBuilder) Delete

func (m *RubricRequestBuilder) Delete() error

Delete delete navigation property rubric for education

func (*RubricRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler added in v0.22.0

func (m *RubricRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler(requestConfiguration *RubricRequestBuilderDeleteRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) error

DeleteWithRequestConfigurationAndResponseHandler delete navigation property rubric for education

func (*RubricRequestBuilder) Get

Get when set, the grading rubric attached to this assignment.

func (*RubricRequestBuilder) GetWithRequestConfigurationAndResponseHandler added in v0.22.0

GetWithRequestConfigurationAndResponseHandler when set, the grading rubric attached to this assignment.

func (*RubricRequestBuilder) Patch

Patch update the navigation property rubric in education

func (*RubricRequestBuilder) PatchWithRequestConfigurationAndResponseHandler added in v0.22.0

PatchWithRequestConfigurationAndResponseHandler update the navigation property rubric in education

func (*RubricRequestBuilder) Ref added in v0.24.0

Ref the ref property

type RubricRequestBuilderDeleteRequestConfiguration added in v0.22.0

type RubricRequestBuilderDeleteRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

RubricRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type RubricRequestBuilderGetQueryParameters

type RubricRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string `uriparametername:"%24expand"`
	// Select properties to be returned
	Select []string `uriparametername:"%24select"`
}

RubricRequestBuilderGetQueryParameters when set, the grading rubric attached to this assignment.

type RubricRequestBuilderGetRequestConfiguration added in v0.22.0

type RubricRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *RubricRequestBuilderGetQueryParameters
}

RubricRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type RubricRequestBuilderPatchRequestConfiguration added in v0.22.0

type RubricRequestBuilderPatchRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

RubricRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Directories

Path Synopsis

Jump to