Documentation
¶
Index ¶
- type OnenoteSectionItemRequestBuilder
- func (m *OnenoteSectionItemRequestBuilder) CopyToNotebook() ...
- func (m *OnenoteSectionItemRequestBuilder) CopyToSectionGroup() ...
- func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation() (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformation() (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) Delete() error
- func (m *OnenoteSectionItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler(...) error
- func (m *OnenoteSectionItemRequestBuilder) Get() (...)
- func (m *OnenoteSectionItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration, ...) (...)
- func (m *OnenoteSectionItemRequestBuilder) Pages() ...
- func (m *OnenoteSectionItemRequestBuilder) PagesById(id string) ...
- func (m *OnenoteSectionItemRequestBuilder) ParentNotebook() ...
- func (m *OnenoteSectionItemRequestBuilder) ParentSectionGroup() ...
- func (m *OnenoteSectionItemRequestBuilder) Patch(...) error
- func (m *OnenoteSectionItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler(...) error
- type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration
- type OnenoteSectionItemRequestBuilderGetQueryParameters
- type OnenoteSectionItemRequestBuilderGetRequestConfiguration
- type OnenoteSectionItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OnenoteSectionItemRequestBuilder ¶ added in v0.12.0
type OnenoteSectionItemRequestBuilder struct {
// contains filtered or unexported fields
}
OnenoteSectionItemRequestBuilder provides operations to manage the sections property of the microsoft.graph.sectionGroup entity.
func NewOnenoteSectionItemRequestBuilder ¶ added in v0.12.0
func NewOnenoteSectionItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OnenoteSectionItemRequestBuilder
NewOnenoteSectionItemRequestBuilder instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
func NewOnenoteSectionItemRequestBuilderInternal ¶ added in v0.12.0
func NewOnenoteSectionItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OnenoteSectionItemRequestBuilder
NewOnenoteSectionItemRequestBuilderInternal instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
func (*OnenoteSectionItemRequestBuilder) CopyToNotebook ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CopyToNotebook() *i6a2573701792c38d1a904928260a42544957096b9336610c03f3577191b269c2.CopyToNotebookRequestBuilder
CopyToNotebook the copyToNotebook property
func (*OnenoteSectionItemRequestBuilder) CopyToSectionGroup ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CopyToSectionGroup() *i0379c1f9a46f8126030a269c68a88d3e9ccc66cc24e43ed04698c023e25c3d39.CopyToSectionGroupRequestBuilder
CopyToSectionGroup the copyToSectionGroup property
func (*OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property sections for groups
func (*OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformationWithRequestConfiguration delete navigation property sections for groups
func (*OnenoteSectionItemRequestBuilder) CreateGetRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property sections in groups
func (*OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, requestConfiguration *OnenoteSectionItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformationWithRequestConfiguration update the navigation property sections in groups
func (*OnenoteSectionItemRequestBuilder) Delete ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Delete() error
Delete delete navigation property sections for groups
func (*OnenoteSectionItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler(requestConfiguration *OnenoteSectionItemRequestBuilderDeleteRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) error
DeleteWithRequestConfigurationAndResponseHandler delete navigation property sections for groups
func (*OnenoteSectionItemRequestBuilder) Get ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Get() (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, error)
Get the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, error)
GetWithRequestConfigurationAndResponseHandler the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) Pages ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Pages() *ib4693e2626a069e883d88bf616b43c63a208420543e04b8c8b90ec7260b09765.PagesRequestBuilder
Pages the pages property
func (*OnenoteSectionItemRequestBuilder) PagesById ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) PagesById(id string) *i8e25c2ac1e76838abeb4a46ec9559d5fbb4331dcdf465ab9c8498acb6ebff813.OnenotePageItemRequestBuilder
PagesById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.groups.item.onenote.sectionGroups.item.sections.item.pages.item collection
func (*OnenoteSectionItemRequestBuilder) ParentNotebook ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) ParentNotebook() *i8cf67e0206ad766d24fb9bd36c150e2839c84d3b6d0e534067b79a8c4c1ed97e.ParentNotebookRequestBuilder
ParentNotebook the parentNotebook property
func (*OnenoteSectionItemRequestBuilder) ParentSectionGroup ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) ParentSectionGroup() *i8ad45a2767b86f0229be8ae61fcec343f671d4cf70bea304ab10e14d59f75e65.ParentSectionGroupRequestBuilder
ParentSectionGroup the parentSectionGroup property
func (*OnenoteSectionItemRequestBuilder) Patch ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Patch(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable) error
Patch update the navigation property sections in groups
func (*OnenoteSectionItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, requestConfiguration *OnenoteSectionItemRequestBuilderPatchRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) error
PatchWithRequestConfigurationAndResponseHandler update the navigation property sections in groups
type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OnenoteSectionItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OnenoteSectionItemRequestBuilderGetQueryParameters ¶ added in v0.12.0
type OnenoteSectionItemRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
OnenoteSectionItemRequestBuilderGetQueryParameters the sections in the section group. Read-only. Nullable.
type OnenoteSectionItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *OnenoteSectionItemRequestBuilderGetQueryParameters
}
OnenoteSectionItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OnenoteSectionItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OnenoteSectionItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.