Documentation
¶
Index ¶
- type RepliesRequestBuilder
- func (m *RepliesRequestBuilder) Count() ...
- func (m *RepliesRequestBuilder) CreateGetRequestInformation() (...)
- func (m *RepliesRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *RepliesRequestBuilderGetRequestConfiguration) (...)
- func (m *RepliesRequestBuilder) CreatePostRequestInformation(...) (...)
- func (m *RepliesRequestBuilder) CreatePostRequestInformationWithRequestConfiguration(...) (...)
- func (m *RepliesRequestBuilder) Delta() ...
- func (m *RepliesRequestBuilder) Get() (...)
- func (m *RepliesRequestBuilder) GetWithRequestConfigurationAndResponseHandler(requestConfiguration *RepliesRequestBuilderGetRequestConfiguration, ...) (...)
- func (m *RepliesRequestBuilder) Post(...) (...)
- func (m *RepliesRequestBuilder) PostWithRequestConfigurationAndResponseHandler(...) (...)
- type RepliesRequestBuilderGetQueryParameters
- type RepliesRequestBuilderGetRequestConfiguration
- type RepliesRequestBuilderPostRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RepliesRequestBuilder ¶
type RepliesRequestBuilder struct {
// contains filtered or unexported fields
}
RepliesRequestBuilder provides operations to manage the replies property of the microsoft.graph.chatMessage entity.
func NewRepliesRequestBuilder ¶
func NewRepliesRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *RepliesRequestBuilder
NewRepliesRequestBuilder instantiates a new RepliesRequestBuilder and sets the default values.
func NewRepliesRequestBuilderInternal ¶
func NewRepliesRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *RepliesRequestBuilder
NewRepliesRequestBuilderInternal instantiates a new RepliesRequestBuilder and sets the default values.
func (*RepliesRequestBuilder) Count ¶
func (m *RepliesRequestBuilder) Count() *ie29ba3342a4cd8603e7009e80c616e5a9ca8ee9f8f050d2a34a70ec9fa7450c3.CountRequestBuilder
Count the count property
func (*RepliesRequestBuilder) CreateGetRequestInformation ¶
func (m *RepliesRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation replies for a specified message. Supports $expand for channel messages.
func (*RepliesRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *RepliesRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *RepliesRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration replies for a specified message. Supports $expand for channel messages.
func (*RepliesRequestBuilder) CreatePostRequestInformation ¶
func (m *RepliesRequestBuilder) CreatePostRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePostRequestInformation create new navigation property to replies for groups
func (*RepliesRequestBuilder) CreatePostRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *RepliesRequestBuilder) CreatePostRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageable, requestConfiguration *RepliesRequestBuilderPostRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePostRequestInformationWithRequestConfiguration create new navigation property to replies for groups
func (*RepliesRequestBuilder) Delta ¶
func (m *RepliesRequestBuilder) Delta() *ied5ad54af32df3c3b522eb9e35e8862fbdf3e9c91fc897a1806e43b79bece134.DeltaRequestBuilder
Delta provides operations to call the delta method.
func (*RepliesRequestBuilder) Get ¶
func (m *RepliesRequestBuilder) Get() (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageCollectionResponseable, error)
Get replies for a specified message. Supports $expand for channel messages.
func (*RepliesRequestBuilder) GetWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *RepliesRequestBuilder) GetWithRequestConfigurationAndResponseHandler(requestConfiguration *RepliesRequestBuilderGetRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageCollectionResponseable, error)
GetWithRequestConfigurationAndResponseHandler replies for a specified message. Supports $expand for channel messages.
func (*RepliesRequestBuilder) Post ¶
func (m *RepliesRequestBuilder) Post(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageable) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageable, error)
Post create new navigation property to replies for groups
func (*RepliesRequestBuilder) PostWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *RepliesRequestBuilder) PostWithRequestConfigurationAndResponseHandler(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageable, requestConfiguration *RepliesRequestBuilderPostRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ChatMessageable, error)
PostWithRequestConfigurationAndResponseHandler create new navigation property to replies for groups
type RepliesRequestBuilderGetQueryParameters ¶
type RepliesRequestBuilderGetQueryParameters struct {
// Include count of items
Count *bool `uriparametername:"%24count"`
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Filter items by property values
Filter *string `uriparametername:"%24filter"`
// Order items by property values
Orderby []string `uriparametername:"%24orderby"`
// Search items by search phrases
Search *string `uriparametername:"%24search"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
// Skip the first n items
Skip *int32 `uriparametername:"%24skip"`
// Show only the first n items
Top *int32 `uriparametername:"%24top"`
}
RepliesRequestBuilderGetQueryParameters replies for a specified message. Supports $expand for channel messages.
type RepliesRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type RepliesRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *RepliesRequestBuilderGetQueryParameters
}
RepliesRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type RepliesRequestBuilderPostRequestConfiguration ¶ added in v0.22.0
type RepliesRequestBuilderPostRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
RepliesRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.