item

package
v0.38.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 9, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AttachmentItemRequestBuilder

type AttachmentItemRequestBuilder struct {
	// contains filtered or unexported fields
}

AttachmentItemRequestBuilder provides operations to manage the attachments property of the microsoft.graph.post entity.

func NewAttachmentItemRequestBuilder

NewAttachmentItemRequestBuilder instantiates a new AttachmentItemRequestBuilder and sets the default values.

func NewAttachmentItemRequestBuilderInternal

func NewAttachmentItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AttachmentItemRequestBuilder

NewAttachmentItemRequestBuilderInternal instantiates a new AttachmentItemRequestBuilder and sets the default values.

func (*AttachmentItemRequestBuilder) CreateDeleteRequestInformation

CreateDeleteRequestInformation delete navigation property attachments for groups

func (*AttachmentItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration added in v0.22.0

CreateDeleteRequestInformationWithRequestConfiguration delete navigation property attachments for groups

func (*AttachmentItemRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation read-only. Nullable. Supports $expand.

func (*AttachmentItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration added in v0.22.0

CreateGetRequestInformationWithRequestConfiguration read-only. Nullable. Supports $expand.

func (*AttachmentItemRequestBuilder) CreatePatchRequestInformation

CreatePatchRequestInformation update the navigation property attachments in groups

func (*AttachmentItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration added in v0.22.0

CreatePatchRequestInformationWithRequestConfiguration update the navigation property attachments in groups

func (*AttachmentItemRequestBuilder) Delete

Delete delete navigation property attachments for groups

func (*AttachmentItemRequestBuilder) Get

Get read-only. Nullable. Supports $expand.

func (*AttachmentItemRequestBuilder) Patch

Patch update the navigation property attachments in groups

type AttachmentItemRequestBuilderDeleteRequestConfiguration added in v0.22.0

type AttachmentItemRequestBuilderDeleteRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

AttachmentItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type AttachmentItemRequestBuilderGetQueryParameters

type AttachmentItemRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string `uriparametername:"%24expand"`
	// Select properties to be returned
	Select []string `uriparametername:"%24select"`
}

AttachmentItemRequestBuilderGetQueryParameters read-only. Nullable. Supports $expand.

type AttachmentItemRequestBuilderGetRequestConfiguration added in v0.22.0

type AttachmentItemRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *AttachmentItemRequestBuilderGetQueryParameters
}

AttachmentItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type AttachmentItemRequestBuilderPatchRequestConfiguration added in v0.22.0

type AttachmentItemRequestBuilderPatchRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

AttachmentItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Jump to