item

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2021 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AttachmentRequestBuilder

type AttachmentRequestBuilder struct {
	// contains filtered or unexported fields
}

AttachmentRequestBuilder builds and executes requests for operations under \me\calendar\events\{event-id}\attachments\{attachment-id}

func NewAttachmentRequestBuilder

NewAttachmentRequestBuilder instantiates a new AttachmentRequestBuilder and sets the default values.

func NewAttachmentRequestBuilderInternal

func NewAttachmentRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *AttachmentRequestBuilder

NewAttachmentRequestBuilderInternal instantiates a new AttachmentRequestBuilder and sets the default values.

func (*AttachmentRequestBuilder) CreateDeleteRequestInformation

CreateDeleteRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

func (*AttachmentRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

func (*AttachmentRequestBuilder) CreatePatchRequestInformation

CreatePatchRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

func (*AttachmentRequestBuilder) Delete

Delete the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

func (*AttachmentRequestBuilder) Get

Get the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

func (*AttachmentRequestBuilder) Patch

Patch the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

type AttachmentRequestBuilderDeleteOptions

type AttachmentRequestBuilderDeleteOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

AttachmentRequestBuilderDeleteOptions options for Delete

type AttachmentRequestBuilderGetOptions

type AttachmentRequestBuilderGetOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Request query parameters
	Q *AttachmentRequestBuilderGetQueryParameters
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

AttachmentRequestBuilderGetOptions options for Get

type AttachmentRequestBuilderGetQueryParameters

type AttachmentRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string
	// Select properties to be returned
	Select []string
}

AttachmentRequestBuilderGetQueryParameters the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.

type AttachmentRequestBuilderPatchOptions

type AttachmentRequestBuilderPatchOptions struct {
	//
	Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.Attachment
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

AttachmentRequestBuilderPatchOptions options for Patch

Jump to