Documentation
¶
Index ¶
- type DriveItemItemRequestBuilder
- func (m *DriveItemItemRequestBuilder) Analytics() ...
- func (m *DriveItemItemRequestBuilder) Checkin() ...
- func (m *DriveItemItemRequestBuilder) Checkout() ...
- func (m *DriveItemItemRequestBuilder) Children() ...
- func (m *DriveItemItemRequestBuilder) ChildrenById(id string) ...
- func (m *DriveItemItemRequestBuilder) Content() ...
- func (m *DriveItemItemRequestBuilder) Copy() ...
- func (m *DriveItemItemRequestBuilder) CreateDeleteRequestInformation(ctx context.Context, ...) (...)
- func (m *DriveItemItemRequestBuilder) CreateGetRequestInformation(ctx context.Context, ...) (...)
- func (m *DriveItemItemRequestBuilder) CreateLink() ...
- func (m *DriveItemItemRequestBuilder) CreatePatchRequestInformation(ctx context.Context, ...) (...)
- func (m *DriveItemItemRequestBuilder) CreateUploadSession() ...
- func (m *DriveItemItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *DriveItemItemRequestBuilder) Delta() ...
- func (m *DriveItemItemRequestBuilder) DeltaWithToken(token *string) ...
- func (m *DriveItemItemRequestBuilder) Follow() ...
- func (m *DriveItemItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *DriveItemItemRequestBuilder) GetActivitiesByInterval() ...
- func (m *DriveItemItemRequestBuilder) GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime *string, interval *string, startDateTime *string) ...
- func (m *DriveItemItemRequestBuilder) Invite() ...
- func (m *DriveItemItemRequestBuilder) ListItem() ...
- func (m *DriveItemItemRequestBuilder) Patch(ctx context.Context, ...) (...)
- func (m *DriveItemItemRequestBuilder) Permissions() ...
- func (m *DriveItemItemRequestBuilder) PermissionsById(id string) ...
- func (m *DriveItemItemRequestBuilder) Preview() ...
- func (m *DriveItemItemRequestBuilder) Restore() ...
- func (m *DriveItemItemRequestBuilder) SearchWithQ(q *string) ...
- func (m *DriveItemItemRequestBuilder) Subscriptions() ...
- func (m *DriveItemItemRequestBuilder) SubscriptionsById(id string) ...
- func (m *DriveItemItemRequestBuilder) Thumbnails() ...
- func (m *DriveItemItemRequestBuilder) ThumbnailsById(id string) ...
- func (m *DriveItemItemRequestBuilder) Unfollow() ...
- func (m *DriveItemItemRequestBuilder) ValidatePermission() ...
- func (m *DriveItemItemRequestBuilder) Versions() ...
- func (m *DriveItemItemRequestBuilder) VersionsById(id string) ...
- type DriveItemItemRequestBuilderDeleteRequestConfiguration
- type DriveItemItemRequestBuilderGetQueryParameters
- type DriveItemItemRequestBuilderGetRequestConfiguration
- type DriveItemItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DriveItemItemRequestBuilder ¶
type DriveItemItemRequestBuilder struct {
// contains filtered or unexported fields
}
DriveItemItemRequestBuilder provides operations to manage the items property of the microsoft.graph.drive entity.
func NewDriveItemItemRequestBuilder ¶
func NewDriveItemItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *DriveItemItemRequestBuilder
NewDriveItemItemRequestBuilder instantiates a new DriveItemItemRequestBuilder and sets the default values.
func NewDriveItemItemRequestBuilderInternal ¶
func NewDriveItemItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *DriveItemItemRequestBuilder
NewDriveItemItemRequestBuilderInternal instantiates a new DriveItemItemRequestBuilder and sets the default values.
func (*DriveItemItemRequestBuilder) Analytics ¶
func (m *DriveItemItemRequestBuilder) Analytics() *ibaffe2d11367d67304962b88ba02d998906cb5eb0f54d8ddbb61bee317476e87.AnalyticsRequestBuilder
Analytics provides operations to manage the analytics property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) Checkin ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Checkin() *i05c0ec45567fb3d8897550eb8ff2422453da4e6f6d020b16f038801c76613cb0.CheckinRequestBuilder
Checkin provides operations to call the checkin method.
func (*DriveItemItemRequestBuilder) Checkout ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Checkout() *ica0c5577a659c2db73294766edd0634bcfb6b46cd86fba6ef3695da20154b5fb.CheckoutRequestBuilder
Checkout provides operations to call the checkout method.
func (*DriveItemItemRequestBuilder) Children ¶
func (m *DriveItemItemRequestBuilder) Children() *ibe02574c8f615741fc45ce6218a6cadf885d6fe1213b9a2728f6c2560f64bc8b.ChildrenRequestBuilder
Children provides operations to manage the children property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) ChildrenById ¶
func (m *DriveItemItemRequestBuilder) ChildrenById(id string) *ic1d7a0ae14cc9523d32ba0aac77590208358c9eb1f33aa8aae89b53a722a2f34.DriveItemItemRequestBuilder
ChildrenById provides operations to manage the children property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) Content ¶
func (m *DriveItemItemRequestBuilder) Content() *i5304ce2548f901afe419817e19c86188c2a91f438d46d99102bb441eeff4f0b3.ContentRequestBuilder
Content provides operations to manage the media for the user entity.
func (*DriveItemItemRequestBuilder) Copy ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Copy() *ife7f55f714b5be81f74d010999842a4ebbe531af12f5e0c350b453baff8d123c.CopyRequestBuilder
Copy provides operations to call the copy method.
func (*DriveItemItemRequestBuilder) CreateDeleteRequestInformation ¶
func (m *DriveItemItemRequestBuilder) CreateDeleteRequestInformation(ctx context.Context, requestConfiguration *DriveItemItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property items for me
func (*DriveItemItemRequestBuilder) CreateGetRequestInformation ¶
func (m *DriveItemItemRequestBuilder) CreateGetRequestInformation(ctx context.Context, requestConfiguration *DriveItemItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation all items contained in the drive. Read-only. Nullable.
func (*DriveItemItemRequestBuilder) CreateLink ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) CreateLink() *i4d19529841f348c677157e7e33d1ed6edd4f81dc72950b477198cfc74d7e39f9.CreateLinkRequestBuilder
CreateLink provides operations to call the createLink method.
func (*DriveItemItemRequestBuilder) CreatePatchRequestInformation ¶
func (m *DriveItemItemRequestBuilder) CreatePatchRequestInformation(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.DriveItemable, requestConfiguration *DriveItemItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property items in me
func (*DriveItemItemRequestBuilder) CreateUploadSession ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) CreateUploadSession() *i9388a70340cfd5e47ba875db1c2e399c8aae526124bab493eb81968bf695efc9.CreateUploadSessionRequestBuilder
CreateUploadSession provides operations to call the createUploadSession method.
func (*DriveItemItemRequestBuilder) Delete ¶
func (m *DriveItemItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *DriveItemItemRequestBuilderDeleteRequestConfiguration) error
Delete delete navigation property items for me
func (*DriveItemItemRequestBuilder) Delta ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Delta() *i30a62b46006f460f830724a34185eabe6addc39b02c7369c642d0f0daa0e55b1.DeltaRequestBuilder
Delta provides operations to call the delta method.
func (*DriveItemItemRequestBuilder) DeltaWithToken ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) DeltaWithToken(token *string) *ic6086ed46c44902cd86e4fbb614c18d42889165eb4282e4c5cad4224a15bec58.DeltaWithTokenRequestBuilder
DeltaWithToken provides operations to call the delta method.
func (*DriveItemItemRequestBuilder) Follow ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Follow() *i5aab00d764a5f9ad9061b7231fa5a867864ca548458690794621d6663cc7494f.FollowRequestBuilder
Follow provides operations to call the follow method.
func (*DriveItemItemRequestBuilder) Get ¶
func (m *DriveItemItemRequestBuilder) Get(ctx context.Context, requestConfiguration *DriveItemItemRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.DriveItemable, error)
Get all items contained in the drive. Read-only. Nullable.
func (*DriveItemItemRequestBuilder) GetActivitiesByInterval ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) GetActivitiesByInterval() *i6310746a06c75ef864413806f6415f3cf09d4e2c5251a2476ed6aca8fb80a235.GetActivitiesByIntervalRequestBuilder
GetActivitiesByInterval provides operations to call the getActivitiesByInterval method.
func (*DriveItemItemRequestBuilder) GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime *string, interval *string, startDateTime *string) *i55bff457bac0cc82d6d6986c1093837e445c6daf83712c030ddc359db974fb0b.GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval provides operations to call the getActivitiesByInterval method.
func (*DriveItemItemRequestBuilder) Invite ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Invite() *i988afeb970a0ba81d62fe3aa5c8bd88ff30fb4b675b544bbaf5d48276346e0d1.InviteRequestBuilder
Invite provides operations to call the invite method.
func (*DriveItemItemRequestBuilder) ListItem ¶
func (m *DriveItemItemRequestBuilder) ListItem() *i746d7e15a556f6f04633a940990ca8cd5733284011c498aa2f3efda3d02ec850.ListItemRequestBuilder
ListItem provides operations to manage the listItem property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) Patch ¶
func (m *DriveItemItemRequestBuilder) Patch(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.DriveItemable, requestConfiguration *DriveItemItemRequestBuilderPatchRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.DriveItemable, error)
Patch update the navigation property items in me
func (*DriveItemItemRequestBuilder) Permissions ¶
func (m *DriveItemItemRequestBuilder) Permissions() *ifab0ee1ab8b0ac70ace5f3a9a8a6be20f9f7bcaa0a4a597c12b0193c63a01bfc.PermissionsRequestBuilder
Permissions provides operations to manage the permissions property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) PermissionsById ¶
func (m *DriveItemItemRequestBuilder) PermissionsById(id string) *i41715f4164032be0448074d9b13e0a1f3deea014767e99c2401d7c0c2be460fa.PermissionItemRequestBuilder
PermissionsById provides operations to manage the permissions property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) Preview ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Preview() *id9c3ac74cd32445dd9c8e64a18843db0fb93f188536cbbff19bcc3146673aa02.PreviewRequestBuilder
Preview provides operations to call the preview method.
func (*DriveItemItemRequestBuilder) Restore ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Restore() *i66dc379faf68048034fe69a71cd7f87234a72e24bc6b264f77d8f56825ced3ea.RestoreRequestBuilder
Restore provides operations to call the restore method.
func (*DriveItemItemRequestBuilder) SearchWithQ ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) SearchWithQ(q *string) *if6a7a6c5900d9d753285a6913fb9e665cb1e4d74b8249bd99a4c3db927fb81a4.SearchWithQRequestBuilder
SearchWithQ provides operations to call the search method.
func (*DriveItemItemRequestBuilder) Subscriptions ¶
func (m *DriveItemItemRequestBuilder) Subscriptions() *i5911408c9fb6d0b7b5506ed43692ffa0e9ef7ea4aa6bb400252473412d679648.SubscriptionsRequestBuilder
Subscriptions provides operations to manage the subscriptions property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) SubscriptionsById ¶
func (m *DriveItemItemRequestBuilder) SubscriptionsById(id string) *i6074b6299f116dcb8c8e4a9411037fe415721114dd52ebb0cc1f250577d97877.SubscriptionItemRequestBuilder
SubscriptionsById provides operations to manage the subscriptions property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) Thumbnails ¶
func (m *DriveItemItemRequestBuilder) Thumbnails() *i697fe94c20cf8aa9d9ca8670aa74113ca512fc7e962733fbc87546eebac86d99.ThumbnailsRequestBuilder
Thumbnails provides operations to manage the thumbnails property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) ThumbnailsById ¶
func (m *DriveItemItemRequestBuilder) ThumbnailsById(id string) *ibbd03e76ea11da931ba857caee75fe5915f32400c809adf19ab65c9715024303.ThumbnailSetItemRequestBuilder
ThumbnailsById provides operations to manage the thumbnails property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) Unfollow ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) Unfollow() *i19d6788f5023c539ef47ca9c3c8aca68e43729ccb50978593ba361436fcbc357.UnfollowRequestBuilder
Unfollow provides operations to call the unfollow method.
func (*DriveItemItemRequestBuilder) ValidatePermission ¶ added in v0.27.0
func (m *DriveItemItemRequestBuilder) ValidatePermission() *iae6a563f2ec29b53d4ce491d2675d9c4d905991ad21aca971dea26f08acd1255.ValidatePermissionRequestBuilder
ValidatePermission provides operations to call the validatePermission method.
func (*DriveItemItemRequestBuilder) Versions ¶
func (m *DriveItemItemRequestBuilder) Versions() *i347de3ec81ee72cada957f9274a2049b35b0a5adeeea551ab42adea127d3020a.VersionsRequestBuilder
Versions provides operations to manage the versions property of the microsoft.graph.driveItem entity.
func (*DriveItemItemRequestBuilder) VersionsById ¶
func (m *DriveItemItemRequestBuilder) VersionsById(id string) *i43d5a4f8297869aa1d898f64c47af83c1f2f56e21d6cbe49173818f05cdb50e6.DriveItemVersionItemRequestBuilder
VersionsById provides operations to manage the versions property of the microsoft.graph.driveItem entity.
type DriveItemItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type DriveItemItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
DriveItemItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type DriveItemItemRequestBuilderGetQueryParameters ¶
type DriveItemItemRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
DriveItemItemRequestBuilderGetQueryParameters all items contained in the drive. Read-only. Nullable.
type DriveItemItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type DriveItemItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *DriveItemItemRequestBuilderGetQueryParameters
}
DriveItemItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type DriveItemItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type DriveItemItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
DriveItemItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.