item

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2022 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TodoTaskRequestBuilder

type TodoTaskRequestBuilder struct {
	// contains filtered or unexported fields
}

TodoTaskRequestBuilder builds and executes requests for operations under \me\todo\lists\{todoTaskList-id}\tasks\{todoTask-id}

func NewTodoTaskRequestBuilder

NewTodoTaskRequestBuilder instantiates a new TodoTaskRequestBuilder and sets the default values.

func NewTodoTaskRequestBuilderInternal

func NewTodoTaskRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *TodoTaskRequestBuilder

NewTodoTaskRequestBuilderInternal instantiates a new TodoTaskRequestBuilder and sets the default values.

func (*TodoTaskRequestBuilder) CreateDeleteRequestInformation

CreateDeleteRequestInformation the tasks in this task list. Read-only. Nullable.

func (*TodoTaskRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation the tasks in this task list. Read-only. Nullable.

func (*TodoTaskRequestBuilder) CreatePatchRequestInformation

CreatePatchRequestInformation the tasks in this task list. Read-only. Nullable.

func (*TodoTaskRequestBuilder) Delete

Delete the tasks in this task list. Read-only. Nullable.

func (*TodoTaskRequestBuilder) ExtensionsById

ExtensionsById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.me.todo.lists.item.tasks.item.extensions.item collection

func (*TodoTaskRequestBuilder) Get

Get the tasks in this task list. Read-only. Nullable.

func (*TodoTaskRequestBuilder) LinkedResourcesById

LinkedResourcesById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.me.todo.lists.item.tasks.item.linkedResources.item collection

func (*TodoTaskRequestBuilder) Patch

Patch the tasks in this task list. Read-only. Nullable.

type TodoTaskRequestBuilderDeleteOptions

type TodoTaskRequestBuilderDeleteOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

TodoTaskRequestBuilderDeleteOptions options for Delete

type TodoTaskRequestBuilderGetOptions

type TodoTaskRequestBuilderGetOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Request query parameters
	Q *TodoTaskRequestBuilderGetQueryParameters
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

TodoTaskRequestBuilderGetOptions options for Get

type TodoTaskRequestBuilderGetQueryParameters

type TodoTaskRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string
	// Select properties to be returned
	Select []string
}

TodoTaskRequestBuilderGetQueryParameters the tasks in this task list. Read-only. Nullable.

type TodoTaskRequestBuilderPatchOptions

type TodoTaskRequestBuilderPatchOptions struct {
	//
	Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.TodoTask
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

TodoTaskRequestBuilderPatchOptions options for Patch

Directories

Path Synopsis

Jump to