item

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2021 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LinkedResourceRequestBuilder

type LinkedResourceRequestBuilder struct {
	// contains filtered or unexported fields
}

LinkedResourceRequestBuilder builds and executes requests for operations under \me\todo\lists\{todoTaskList-id}\tasks\{todoTask-id}\linkedResources\{linkedResource-id}

func NewLinkedResourceRequestBuilder

NewLinkedResourceRequestBuilder instantiates a new LinkedResourceRequestBuilder and sets the default values.

func NewLinkedResourceRequestBuilderInternal

func NewLinkedResourceRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *LinkedResourceRequestBuilder

NewLinkedResourceRequestBuilderInternal instantiates a new LinkedResourceRequestBuilder and sets the default values.

func (*LinkedResourceRequestBuilder) CreateDeleteRequestInformation

CreateDeleteRequestInformation a collection of resources linked to the task.

func (*LinkedResourceRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation a collection of resources linked to the task.

func (*LinkedResourceRequestBuilder) CreatePatchRequestInformation

CreatePatchRequestInformation a collection of resources linked to the task.

func (*LinkedResourceRequestBuilder) Delete

Delete a collection of resources linked to the task.

func (*LinkedResourceRequestBuilder) Get

Get a collection of resources linked to the task.

func (*LinkedResourceRequestBuilder) Patch

Patch a collection of resources linked to the task.

type LinkedResourceRequestBuilderDeleteOptions

type LinkedResourceRequestBuilderDeleteOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

LinkedResourceRequestBuilderDeleteOptions options for Delete

type LinkedResourceRequestBuilderGetOptions

type LinkedResourceRequestBuilderGetOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Request query parameters
	Q *LinkedResourceRequestBuilderGetQueryParameters
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

LinkedResourceRequestBuilderGetOptions options for Get

type LinkedResourceRequestBuilderGetQueryParameters

type LinkedResourceRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string
	// Select properties to be returned
	Select []string
}

LinkedResourceRequestBuilderGetQueryParameters a collection of resources linked to the task.

type LinkedResourceRequestBuilderPatchOptions

type LinkedResourceRequestBuilderPatchOptions struct {
	//
	Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.LinkedResource
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

LinkedResourceRequestBuilderPatchOptions options for Patch

Jump to