definition

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DefinitionRequestBuilder

type DefinitionRequestBuilder struct {
	// contains filtered or unexported fields
}

DefinitionRequestBuilder provides operations to manage the definition property of the microsoft.graph.printTaskTrigger entity.

func NewDefinitionRequestBuilder

NewDefinitionRequestBuilder instantiates a new DefinitionRequestBuilder and sets the default values.

func NewDefinitionRequestBuilderInternal

func NewDefinitionRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *DefinitionRequestBuilder

NewDefinitionRequestBuilderInternal instantiates a new DefinitionRequestBuilder and sets the default values.

func (*DefinitionRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation an abstract definition that will be used to create a printTask when triggered by a print event. Read-only.

func (*DefinitionRequestBuilder) CreateGetRequestInformationWithRequestConfiguration added in v0.22.0

CreateGetRequestInformationWithRequestConfiguration an abstract definition that will be used to create a printTask when triggered by a print event. Read-only.

func (*DefinitionRequestBuilder) Get

Get an abstract definition that will be used to create a printTask when triggered by a print event. Read-only.

func (*DefinitionRequestBuilder) GetWithRequestConfigurationAndResponseHandler added in v0.22.0

GetWithRequestConfigurationAndResponseHandler an abstract definition that will be used to create a printTask when triggered by a print event. Read-only.

type DefinitionRequestBuilderGetQueryParameters

type DefinitionRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string `uriparametername:"%24expand"`
	// Select properties to be returned
	Select []string `uriparametername:"%24select"`
}

DefinitionRequestBuilderGetQueryParameters an abstract definition that will be used to create a printTask when triggered by a print event. Read-only.

type DefinitionRequestBuilderGetRequestConfiguration added in v0.22.0

type DefinitionRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *DefinitionRequestBuilderGetQueryParameters
}

DefinitionRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Jump to