basetypes

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2022 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BaseTypesRequestBuilder

type BaseTypesRequestBuilder struct {
	// contains filtered or unexported fields
}

BaseTypesRequestBuilder builds and executes requests for operations under \shares\{sharedDriveItem-id}\list\contentTypes\{contentType-id}\baseTypes

func NewBaseTypesRequestBuilder

NewBaseTypesRequestBuilder instantiates a new BaseTypesRequestBuilder and sets the default values.

func NewBaseTypesRequestBuilderInternal

func NewBaseTypesRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *BaseTypesRequestBuilder

NewBaseTypesRequestBuilderInternal instantiates a new BaseTypesRequestBuilder and sets the default values.

func (*BaseTypesRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation the collection of content types that are ancestors of this content type.

func (*BaseTypesRequestBuilder) Get

Get the collection of content types that are ancestors of this content type.

type BaseTypesRequestBuilderGetOptions

type BaseTypesRequestBuilderGetOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Request query parameters
	Q *BaseTypesRequestBuilderGetQueryParameters
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

BaseTypesRequestBuilderGetOptions options for Get

type BaseTypesRequestBuilderGetQueryParameters

type BaseTypesRequestBuilderGetQueryParameters struct {
	// Include count of items
	Count *bool
	// Expand related entities
	Expand []string
	// Filter items by property values
	Filter *string
	// Order items by property values
	Orderby []string
	// Search items by search phrases
	Search *string
	// Select properties to be returned
	Select []string
	// Skip the first n items
	Skip *int32
	// Show only the first n items
	Top *int32
}

BaseTypesRequestBuilderGetQueryParameters the collection of content types that are ancestors of this content type.

type BaseTypesResponse

type BaseTypesResponse struct {
	// contains filtered or unexported fields
}

BaseTypesResponse

func NewBaseTypesResponse

func NewBaseTypesResponse() *BaseTypesResponse

NewBaseTypesResponse instantiates a new baseTypesResponse and sets the default values.

func (*BaseTypesResponse) GetAdditionalData

func (m *BaseTypesResponse) GetAdditionalData() map[string]interface{}

GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*BaseTypesResponse) GetFieldDeserializers

GetFieldDeserializers the deserialization information for the current model

func (m *BaseTypesResponse) GetNextLink() *string

GetNextLink gets the @odata.nextLink property value.

func (*BaseTypesResponse) GetValue

GetValue gets the value property value.

func (*BaseTypesResponse) IsNil

func (m *BaseTypesResponse) IsNil() bool

func (*BaseTypesResponse) Serialize

Serialize serializes information the current object

func (*BaseTypesResponse) SetAdditionalData

func (m *BaseTypesResponse) SetAdditionalData(value map[string]interface{})

SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (m *BaseTypesResponse) SetNextLink(value *string)

SetNextLink sets the @odata.nextLink property value.

func (*BaseTypesResponse) SetValue

SetValue sets the value property value.

Directories

Path Synopsis

Jump to