associatewithhubsites

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateAssociateWithHubSitesPostRequestBodyFromDiscriminatorValue added in v0.24.0

CreateAssociateWithHubSitesPostRequestBodyFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value

Types

type AssociateWithHubSitesPostRequestBody added in v0.24.0

type AssociateWithHubSitesPostRequestBody struct {
	// contains filtered or unexported fields
}

AssociateWithHubSitesPostRequestBody provides operations to call the associateWithHubSites method.

func NewAssociateWithHubSitesPostRequestBody added in v0.24.0

func NewAssociateWithHubSitesPostRequestBody() *AssociateWithHubSitesPostRequestBody

NewAssociateWithHubSitesPostRequestBody instantiates a new associateWithHubSitesPostRequestBody and sets the default values.

func (*AssociateWithHubSitesPostRequestBody) GetAdditionalData added in v0.24.0

func (m *AssociateWithHubSitesPostRequestBody) GetAdditionalData() map[string]interface{}

GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*AssociateWithHubSitesPostRequestBody) GetFieldDeserializers added in v0.24.0

GetFieldDeserializers the deserialization information for the current model

func (*AssociateWithHubSitesPostRequestBody) GetHubSiteUrls added in v0.24.0

func (m *AssociateWithHubSitesPostRequestBody) GetHubSiteUrls() []string

GetHubSiteUrls gets the hubSiteUrls property value. The hubSiteUrls property

func (*AssociateWithHubSitesPostRequestBody) GetPropagateToExistingLists added in v0.24.0

func (m *AssociateWithHubSitesPostRequestBody) GetPropagateToExistingLists() *bool

GetPropagateToExistingLists gets the propagateToExistingLists property value. The propagateToExistingLists property

func (*AssociateWithHubSitesPostRequestBody) Serialize added in v0.24.0

Serialize serializes information the current object

func (*AssociateWithHubSitesPostRequestBody) SetAdditionalData added in v0.24.0

func (m *AssociateWithHubSitesPostRequestBody) SetAdditionalData(value map[string]interface{})

SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*AssociateWithHubSitesPostRequestBody) SetHubSiteUrls added in v0.24.0

func (m *AssociateWithHubSitesPostRequestBody) SetHubSiteUrls(value []string)

SetHubSiteUrls sets the hubSiteUrls property value. The hubSiteUrls property

func (*AssociateWithHubSitesPostRequestBody) SetPropagateToExistingLists added in v0.24.0

func (m *AssociateWithHubSitesPostRequestBody) SetPropagateToExistingLists(value *bool)

SetPropagateToExistingLists sets the propagateToExistingLists property value. The propagateToExistingLists property

type AssociateWithHubSitesPostRequestBodyable added in v0.24.0

type AssociateWithHubSitesPostRequestBodyable interface {
	i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.AdditionalDataHolder
	i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
	GetHubSiteUrls() []string
	GetPropagateToExistingLists() *bool
	SetHubSiteUrls(value []string)
	SetPropagateToExistingLists(value *bool)
}

AssociateWithHubSitesPostRequestBodyable

type AssociateWithHubSitesRequestBuilder

type AssociateWithHubSitesRequestBuilder struct {
	// contains filtered or unexported fields
}

AssociateWithHubSitesRequestBuilder provides operations to call the associateWithHubSites method.

func NewAssociateWithHubSitesRequestBuilder

NewAssociateWithHubSitesRequestBuilder instantiates a new AssociateWithHubSitesRequestBuilder and sets the default values.

func NewAssociateWithHubSitesRequestBuilderInternal

func NewAssociateWithHubSitesRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AssociateWithHubSitesRequestBuilder

NewAssociateWithHubSitesRequestBuilderInternal instantiates a new AssociateWithHubSitesRequestBuilder and sets the default values.

func (*AssociateWithHubSitesRequestBuilder) CreatePostRequestInformation

CreatePostRequestInformation invoke action associateWithHubSites

func (*AssociateWithHubSitesRequestBuilder) CreatePostRequestInformationWithRequestConfiguration added in v0.22.0

CreatePostRequestInformationWithRequestConfiguration invoke action associateWithHubSites

func (*AssociateWithHubSitesRequestBuilder) Post

Post invoke action associateWithHubSites

func (*AssociateWithHubSitesRequestBuilder) PostWithRequestConfigurationAndResponseHandler added in v0.22.0

PostWithRequestConfigurationAndResponseHandler invoke action associateWithHubSites

type AssociateWithHubSitesRequestBuilderPostRequestConfiguration added in v0.22.0

type AssociateWithHubSitesRequestBuilderPostRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

AssociateWithHubSitesRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Jump to