item

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DriveItemRequestBuilder added in v0.13.0

type DriveItemRequestBuilder struct {
	// contains filtered or unexported fields
}

DriveItemRequestBuilder provides operations to manage the drives property of the microsoft.graph.site entity.

func NewDriveItemRequestBuilder added in v0.13.0

NewDriveItemRequestBuilder instantiates a new DriveItemRequestBuilder and sets the default values.

func NewDriveItemRequestBuilderInternal added in v0.13.0

func NewDriveItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *DriveItemRequestBuilder

NewDriveItemRequestBuilderInternal instantiates a new DriveItemRequestBuilder and sets the default values.

func (*DriveItemRequestBuilder) CreateGetRequestInformation added in v0.13.0

CreateGetRequestInformation the collection of drives (document libraries) under this site.

func (*DriveItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration added in v0.22.0

CreateGetRequestInformationWithRequestConfiguration the collection of drives (document libraries) under this site.

func (*DriveItemRequestBuilder) Get added in v0.13.0

Get the collection of drives (document libraries) under this site.

func (*DriveItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler added in v0.22.0

GetWithRequestConfigurationAndResponseHandler the collection of drives (document libraries) under this site.

type DriveItemRequestBuilderGetQueryParameters added in v0.13.0

type DriveItemRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string `uriparametername:"%24expand"`
	// Select properties to be returned
	Select []string `uriparametername:"%24select"`
}

DriveItemRequestBuilderGetQueryParameters the collection of drives (document libraries) under this site.

type DriveItemRequestBuilderGetRequestConfiguration added in v0.22.0

type DriveItemRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *DriveItemRequestBuilderGetQueryParameters
}

DriveItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Jump to