Documentation
¶
Index ¶
- type OnenoteSectionItemRequestBuilder
- func (m *OnenoteSectionItemRequestBuilder) CopyToNotebook() ...
- func (m *OnenoteSectionItemRequestBuilder) CopyToSectionGroup() ...
- func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation() (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformation() (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *OnenoteSectionItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *OnenoteSectionItemRequestBuilder) Pages() ...
- func (m *OnenoteSectionItemRequestBuilder) PagesById(id string) ...
- func (m *OnenoteSectionItemRequestBuilder) ParentNotebook() ...
- func (m *OnenoteSectionItemRequestBuilder) ParentSectionGroup() ...
- func (m *OnenoteSectionItemRequestBuilder) Patch(ctx context.Context, ...) error
- type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration
- type OnenoteSectionItemRequestBuilderGetQueryParameters
- type OnenoteSectionItemRequestBuilderGetRequestConfiguration
- type OnenoteSectionItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OnenoteSectionItemRequestBuilder ¶ added in v0.12.0
type OnenoteSectionItemRequestBuilder struct {
// contains filtered or unexported fields
}
OnenoteSectionItemRequestBuilder provides operations to manage the sections property of the microsoft.graph.notebook entity.
func NewOnenoteSectionItemRequestBuilder ¶ added in v0.12.0
func NewOnenoteSectionItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OnenoteSectionItemRequestBuilder
NewOnenoteSectionItemRequestBuilder instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
func NewOnenoteSectionItemRequestBuilderInternal ¶ added in v0.12.0
func NewOnenoteSectionItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OnenoteSectionItemRequestBuilder
NewOnenoteSectionItemRequestBuilderInternal instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
func (*OnenoteSectionItemRequestBuilder) CopyToNotebook ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CopyToNotebook() *i44235afe4d281e29e2cd6b9abe12f703ec1959f43cd3be6ea227b53da7492dd7.CopyToNotebookRequestBuilder
CopyToNotebook the copyToNotebook property
func (*OnenoteSectionItemRequestBuilder) CopyToSectionGroup ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CopyToSectionGroup() *i0788ee8cc0f88534473ad867f6033f79c94d3ced1d865def09e887a4af6505f0.CopyToSectionGroupRequestBuilder
CopyToSectionGroup the copyToSectionGroup property
func (*OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property sections for sites
func (*OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformationWithRequestConfiguration delete navigation property sections for sites
func (*OnenoteSectionItemRequestBuilder) CreateGetRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the sections in the notebook. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration the sections in the notebook. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property sections in sites
func (*OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, requestConfiguration *OnenoteSectionItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformationWithRequestConfiguration update the navigation property sections in sites
func (*OnenoteSectionItemRequestBuilder) Delete ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *OnenoteSectionItemRequestBuilderDeleteRequestConfiguration) error
Delete delete navigation property sections for sites
func (*OnenoteSectionItemRequestBuilder) Get ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Get(ctx context.Context, requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, error)
Get the sections in the notebook. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) Pages ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Pages() *i090eb63c39e2c392547c70c8250c04ea9dc1ea28fd27551825475fe51dedb728.PagesRequestBuilder
Pages the pages property
func (*OnenoteSectionItemRequestBuilder) PagesById ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) PagesById(id string) *icd8f355cf1b63abcb90f8942bfacbc3a61d12900f6fa5545795d228102f51471.OnenotePageItemRequestBuilder
PagesById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.sites.item.onenote.notebooks.item.sections.item.pages.item collection
func (*OnenoteSectionItemRequestBuilder) ParentNotebook ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) ParentNotebook() *i7fda827a8abe7ff3582c46ee5993acec0f2c7f7fe245e0e35e98367e8db423c5.ParentNotebookRequestBuilder
ParentNotebook the parentNotebook property
func (*OnenoteSectionItemRequestBuilder) ParentSectionGroup ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) ParentSectionGroup() *i84bdfed9ec30dc209a4c530b508d815c14183bd652a5999a2f6f72613165ac5b.ParentSectionGroupRequestBuilder
ParentSectionGroup the parentSectionGroup property
func (*OnenoteSectionItemRequestBuilder) Patch ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Patch(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, requestConfiguration *OnenoteSectionItemRequestBuilderPatchRequestConfiguration) error
Patch update the navigation property sections in sites
type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OnenoteSectionItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OnenoteSectionItemRequestBuilderGetQueryParameters ¶ added in v0.12.0
type OnenoteSectionItemRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
OnenoteSectionItemRequestBuilderGetQueryParameters the sections in the notebook. Read-only. Nullable.
type OnenoteSectionItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *OnenoteSectionItemRequestBuilderGetQueryParameters
}
OnenoteSectionItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OnenoteSectionItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OnenoteSectionItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.