Documentation
¶
Index ¶
- type SectionGroupRequestBuilder
- func (m *SectionGroupRequestBuilder) CreateDeleteRequestInformation(options *SectionGroupRequestBuilderDeleteOptions) (...)
- func (m *SectionGroupRequestBuilder) CreateGetRequestInformation(options *SectionGroupRequestBuilderGetOptions) (...)
- func (m *SectionGroupRequestBuilder) CreatePatchRequestInformation(options *SectionGroupRequestBuilderPatchOptions) (...)
- func (m *SectionGroupRequestBuilder) Delete(options *SectionGroupRequestBuilderDeleteOptions) error
- func (m *SectionGroupRequestBuilder) Get(options *SectionGroupRequestBuilderGetOptions) (...)
- func (m *SectionGroupRequestBuilder) Patch(options *SectionGroupRequestBuilderPatchOptions) error
- type SectionGroupRequestBuilderDeleteOptions
- type SectionGroupRequestBuilderGetOptions
- type SectionGroupRequestBuilderGetQueryParameters
- type SectionGroupRequestBuilderPatchOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SectionGroupRequestBuilder ¶
type SectionGroupRequestBuilder struct {
// contains filtered or unexported fields
}
Builds and executes requests for operations under \sites\{site-id}\onenote\sectionGroups\{sectionGroup-id}\parentNotebook\sectionGroups\{sectionGroup-id1}
func NewSectionGroupRequestBuilder ¶
func NewSectionGroupRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *SectionGroupRequestBuilder
Instantiates a new SectionGroupRequestBuilder and sets the default values. Parameters:
- rawUrl : The raw URL to use for the request builder.
- requestAdapter : The request adapter to use to execute the requests.
func NewSectionGroupRequestBuilderInternal ¶
func NewSectionGroupRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *SectionGroupRequestBuilder
Instantiates a new SectionGroupRequestBuilder and sets the default values. Parameters:
- pathParameters : Path parameters for the request
- requestAdapter : The request adapter to use to execute the requests.
func (*SectionGroupRequestBuilder) CreateDeleteRequestInformation ¶
func (m *SectionGroupRequestBuilder) CreateDeleteRequestInformation(options *SectionGroupRequestBuilderDeleteOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The section groups in the notebook. Read-only. Nullable. Parameters:
- options : Options for the request
func (*SectionGroupRequestBuilder) CreateGetRequestInformation ¶
func (m *SectionGroupRequestBuilder) CreateGetRequestInformation(options *SectionGroupRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The section groups in the notebook. Read-only. Nullable. Parameters:
- options : Options for the request
func (*SectionGroupRequestBuilder) CreatePatchRequestInformation ¶
func (m *SectionGroupRequestBuilder) CreatePatchRequestInformation(options *SectionGroupRequestBuilderPatchOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The section groups in the notebook. Read-only. Nullable. Parameters:
- options : Options for the request
func (*SectionGroupRequestBuilder) Delete ¶
func (m *SectionGroupRequestBuilder) Delete(options *SectionGroupRequestBuilderDeleteOptions) error
The section groups in the notebook. Read-only. Nullable. Parameters:
- options : Options for the request
func (*SectionGroupRequestBuilder) Get ¶
func (m *SectionGroupRequestBuilder) Get(options *SectionGroupRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.SectionGroup, error)
The section groups in the notebook. Read-only. Nullable. Parameters:
- options : Options for the request
func (*SectionGroupRequestBuilder) Patch ¶
func (m *SectionGroupRequestBuilder) Patch(options *SectionGroupRequestBuilderPatchOptions) error
The section groups in the notebook. Read-only. Nullable. Parameters:
- options : Options for the request
type SectionGroupRequestBuilderDeleteOptions ¶
type SectionGroupRequestBuilderDeleteOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Delete
type SectionGroupRequestBuilderGetOptions ¶
type SectionGroupRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *SectionGroupRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Get
type SectionGroupRequestBuilderGetQueryParameters ¶
type SectionGroupRequestBuilderGetQueryParameters struct {
ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.QueryParametersBase
// Expand related entities
Expand []string
// Select properties to be returned
Select_escaped []string
}
The section groups in the notebook. Read-only. Nullable.
type SectionGroupRequestBuilderPatchOptions ¶
type SectionGroupRequestBuilderPatchOptions struct {
//
Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.SectionGroup
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Patch