set

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SetRequestBuilder

type SetRequestBuilder struct {
	// contains filtered or unexported fields
}

SetRequestBuilder builds and executes requests for operations under \sites\{site-id}\termStore\sets\{set-id}\terms\{term-id}\set

func NewSetRequestBuilder

NewSetRequestBuilder instantiates a new SetRequestBuilder and sets the default values.

func NewSetRequestBuilderInternal

func NewSetRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *SetRequestBuilder

NewSetRequestBuilderInternal instantiates a new SetRequestBuilder and sets the default values.

func (*SetRequestBuilder) CreateGetRequestInformation

CreateGetRequestInformation the set in which the term is created.

func (*SetRequestBuilder) Get

Get the set in which the term is created.

type SetRequestBuilderGetOptions

type SetRequestBuilderGetOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Request query parameters
	Q *SetRequestBuilderGetQueryParameters
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

SetRequestBuilderGetOptions options for Get

type SetRequestBuilderGetQueryParameters

type SetRequestBuilderGetQueryParameters struct {
	// Expand related entities
	Expand []string
	// Select properties to be returned
	Select []string
}

SetRequestBuilderGetQueryParameters the set in which the term is created.

Directories

Path Synopsis

Jump to