Documentation
¶
Index ¶
- type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder
- func NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder(rawUrl string, ...) *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder
- func NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderInternal(pathParameters map[string]string, ...) *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreateDeleteRequestInformation(ctx context.Context, ...) (...)
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreateGetRequestInformation(ctx context.Context, ...) (...)
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreatePatchRequestInformation(ctx context.Context, ...) (...)
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Device() ...
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Patch(ctx context.Context, ...) (...)
- type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderDeleteRequestConfiguration
- type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetQueryParameters
- type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetRequestConfiguration
- type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder ¶ added in v0.12.0
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder struct {
// contains filtered or unexported fields
}
MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder provides operations to manage the microsoftAuthenticatorMethods property of the microsoft.graph.authentication entity.
func NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder ¶ added in v0.12.0
func NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder
NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder instantiates a new MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder and sets the default values.
func NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderInternal ¶ added in v0.12.0
func NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder
NewMicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderInternal instantiates a new MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder and sets the default values.
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreateDeleteRequestInformation ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreateDeleteRequestInformation(ctx context.Context, requestConfiguration *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property microsoftAuthenticatorMethods for users
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreateGetRequestInformation ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreateGetRequestInformation(ctx context.Context, requestConfiguration *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the details of the Microsoft Authenticator app registered to a user for authentication.
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreatePatchRequestInformation ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) CreatePatchRequestInformation(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.MicrosoftAuthenticatorAuthenticationMethodable, requestConfiguration *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property microsoftAuthenticatorMethods in users
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Delete ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderDeleteRequestConfiguration) error
Delete delete navigation property microsoftAuthenticatorMethods for users
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Device ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Device() *ifce57a57adfd7290b293a3e17c5be0796fea90e87fd8cf8b6f8988ea949ad506.DeviceRequestBuilder
Device the device property
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Get ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Get(ctx context.Context, requestConfiguration *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.MicrosoftAuthenticatorAuthenticationMethodable, error)
Get the details of the Microsoft Authenticator app registered to a user for authentication.
func (*MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Patch ¶ added in v0.12.0
func (m *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder) Patch(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.MicrosoftAuthenticatorAuthenticationMethodable, requestConfiguration *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderPatchRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.MicrosoftAuthenticatorAuthenticationMethodable, error)
Patch update the navigation property microsoftAuthenticatorMethods in users
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetQueryParameters ¶ added in v0.12.0
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetQueryParameters the details of the Microsoft Authenticator app registered to a user for authentication.
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetQueryParameters
}
MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.