Documentation
¶
Index ¶
- type ChildFoldersRequestBuilder
- func (m *ChildFoldersRequestBuilder) Count() ...
- func (m *ChildFoldersRequestBuilder) CreateGetRequestInformation() (...)
- func (m *ChildFoldersRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *ChildFoldersRequestBuilderGetRequestConfiguration) (...)
- func (m *ChildFoldersRequestBuilder) CreatePostRequestInformation(...) (...)
- func (m *ChildFoldersRequestBuilder) CreatePostRequestInformationWithRequestConfiguration(...) (...)
- func (m *ChildFoldersRequestBuilder) Delta() ...
- func (m *ChildFoldersRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *ChildFoldersRequestBuilder) Post(ctx context.Context, ...) (...)
- type ChildFoldersRequestBuilderGetQueryParameters
- type ChildFoldersRequestBuilderGetRequestConfiguration
- type ChildFoldersRequestBuilderPostRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChildFoldersRequestBuilder ¶
type ChildFoldersRequestBuilder struct {
// contains filtered or unexported fields
}
ChildFoldersRequestBuilder provides operations to manage the childFolders property of the microsoft.graph.contactFolder entity.
func NewChildFoldersRequestBuilder ¶
func NewChildFoldersRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ChildFoldersRequestBuilder
NewChildFoldersRequestBuilder instantiates a new ChildFoldersRequestBuilder and sets the default values.
func NewChildFoldersRequestBuilderInternal ¶
func NewChildFoldersRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ChildFoldersRequestBuilder
NewChildFoldersRequestBuilderInternal instantiates a new ChildFoldersRequestBuilder and sets the default values.
func (*ChildFoldersRequestBuilder) Count ¶ added in v0.13.0
func (m *ChildFoldersRequestBuilder) Count() *i8ff725fb3e0a0491b513430dc54ad671e4f4fc4db052401a39d41e5e6ca87984.CountRequestBuilder
Count the Count property
func (*ChildFoldersRequestBuilder) CreateGetRequestInformation ¶
func (m *ChildFoldersRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the collection of child folders in the folder. Navigation property. Read-only. Nullable.
func (*ChildFoldersRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *ChildFoldersRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *ChildFoldersRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration the collection of child folders in the folder. Navigation property. Read-only. Nullable.
func (*ChildFoldersRequestBuilder) CreatePostRequestInformation ¶
func (m *ChildFoldersRequestBuilder) CreatePostRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ContactFolderable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePostRequestInformation create new navigation property to childFolders for users
func (*ChildFoldersRequestBuilder) CreatePostRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *ChildFoldersRequestBuilder) CreatePostRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ContactFolderable, requestConfiguration *ChildFoldersRequestBuilderPostRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePostRequestInformationWithRequestConfiguration create new navigation property to childFolders for users
func (*ChildFoldersRequestBuilder) Delta ¶
func (m *ChildFoldersRequestBuilder) Delta() *if10b1df627241dcf37089f24077e52bd86d9374795620947745a09de995c6c5a.DeltaRequestBuilder
Delta provides operations to call the delta method.
func (*ChildFoldersRequestBuilder) Get ¶
func (m *ChildFoldersRequestBuilder) Get(ctx context.Context, requestConfiguration *ChildFoldersRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ContactFolderCollectionResponseable, error)
Get the collection of child folders in the folder. Navigation property. Read-only. Nullable.
func (*ChildFoldersRequestBuilder) Post ¶
func (m *ChildFoldersRequestBuilder) Post(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ContactFolderable, requestConfiguration *ChildFoldersRequestBuilderPostRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ContactFolderable, error)
Post create new navigation property to childFolders for users
type ChildFoldersRequestBuilderGetQueryParameters ¶
type ChildFoldersRequestBuilderGetQueryParameters struct {
// Include count of items
Count *bool `uriparametername:"%24count"`
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Filter items by property values
Filter *string `uriparametername:"%24filter"`
// Order items by property values
Orderby []string `uriparametername:"%24orderby"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
// Skip the first n items
Skip *int32 `uriparametername:"%24skip"`
// Show only the first n items
Top *int32 `uriparametername:"%24top"`
}
ChildFoldersRequestBuilderGetQueryParameters the collection of child folders in the folder. Navigation property. Read-only. Nullable.
type ChildFoldersRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type ChildFoldersRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *ChildFoldersRequestBuilderGetQueryParameters
}
ChildFoldersRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ChildFoldersRequestBuilderPostRequestConfiguration ¶ added in v0.22.0
type ChildFoldersRequestBuilderPostRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ChildFoldersRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.