replyall

package
v0.33.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateReplyAllPostRequestBodyFromDiscriminatorValue added in v0.24.0

CreateReplyAllPostRequestBodyFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value

Types

type ReplyAllPostRequestBody added in v0.24.0

type ReplyAllPostRequestBody struct {
	// contains filtered or unexported fields
}

ReplyAllPostRequestBody provides operations to call the replyAll method.

func NewReplyAllPostRequestBody added in v0.24.0

func NewReplyAllPostRequestBody() *ReplyAllPostRequestBody

NewReplyAllPostRequestBody instantiates a new replyAllPostRequestBody and sets the default values.

func (*ReplyAllPostRequestBody) GetAdditionalData added in v0.24.0

func (m *ReplyAllPostRequestBody) GetAdditionalData() map[string]interface{}

GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*ReplyAllPostRequestBody) GetComment added in v0.24.0

func (m *ReplyAllPostRequestBody) GetComment() *string

GetComment gets the comment property value. The Comment property

func (*ReplyAllPostRequestBody) GetFieldDeserializers added in v0.24.0

GetFieldDeserializers the deserialization information for the current model

func (*ReplyAllPostRequestBody) GetMessage added in v0.24.0

GetMessage gets the message property value. The Message property

func (*ReplyAllPostRequestBody) Serialize added in v0.24.0

Serialize serializes information the current object

func (*ReplyAllPostRequestBody) SetAdditionalData added in v0.24.0

func (m *ReplyAllPostRequestBody) SetAdditionalData(value map[string]interface{})

SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*ReplyAllPostRequestBody) SetComment added in v0.24.0

func (m *ReplyAllPostRequestBody) SetComment(value *string)

SetComment sets the comment property value. The Comment property

func (*ReplyAllPostRequestBody) SetMessage added in v0.24.0

SetMessage sets the message property value. The Message property

type ReplyAllRequestBuilder

type ReplyAllRequestBuilder struct {
	// contains filtered or unexported fields
}

ReplyAllRequestBuilder provides operations to call the replyAll method.

func NewReplyAllRequestBuilder

NewReplyAllRequestBuilder instantiates a new ReplyAllRequestBuilder and sets the default values.

func NewReplyAllRequestBuilderInternal

func NewReplyAllRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ReplyAllRequestBuilder

NewReplyAllRequestBuilderInternal instantiates a new ReplyAllRequestBuilder and sets the default values.

func (*ReplyAllRequestBuilder) CreatePostRequestInformation

CreatePostRequestInformation invoke action replyAll

func (*ReplyAllRequestBuilder) CreatePostRequestInformationWithRequestConfiguration added in v0.22.0

CreatePostRequestInformationWithRequestConfiguration invoke action replyAll

func (*ReplyAllRequestBuilder) Post

Post invoke action replyAll

func (*ReplyAllRequestBuilder) PostWithRequestConfigurationAndResponseHandler added in v0.22.0

PostWithRequestConfigurationAndResponseHandler invoke action replyAll

type ReplyAllRequestBuilderPostRequestConfiguration added in v0.22.0

type ReplyAllRequestBuilderPostRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

ReplyAllRequestBuilderPostRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Jump to