Documentation
¶
Index ¶
- type OnenoteSectionItemRequestBuilder
- func (m *OnenoteSectionItemRequestBuilder) CopyToNotebook() ...
- func (m *OnenoteSectionItemRequestBuilder) CopyToSectionGroup() ...
- func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation() (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformation() (...)
- func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(...) (...)
- func (m *OnenoteSectionItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *OnenoteSectionItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *OnenoteSectionItemRequestBuilder) Pages() ...
- func (m *OnenoteSectionItemRequestBuilder) PagesById(id string) ...
- func (m *OnenoteSectionItemRequestBuilder) ParentNotebook() ...
- func (m *OnenoteSectionItemRequestBuilder) ParentSectionGroup() ...
- func (m *OnenoteSectionItemRequestBuilder) Patch(ctx context.Context, ...) error
- type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration
- type OnenoteSectionItemRequestBuilderGetQueryParameters
- type OnenoteSectionItemRequestBuilderGetRequestConfiguration
- type OnenoteSectionItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OnenoteSectionItemRequestBuilder ¶ added in v0.12.0
type OnenoteSectionItemRequestBuilder struct {
// contains filtered or unexported fields
}
OnenoteSectionItemRequestBuilder provides operations to manage the sections property of the microsoft.graph.sectionGroup entity.
func NewOnenoteSectionItemRequestBuilder ¶ added in v0.12.0
func NewOnenoteSectionItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OnenoteSectionItemRequestBuilder
NewOnenoteSectionItemRequestBuilder instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
func NewOnenoteSectionItemRequestBuilderInternal ¶ added in v0.12.0
func NewOnenoteSectionItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OnenoteSectionItemRequestBuilder
NewOnenoteSectionItemRequestBuilderInternal instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
func (*OnenoteSectionItemRequestBuilder) CopyToNotebook ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CopyToNotebook() *i660ed7bde77c43f34ca35cf771422ef1031fbdd787555e46ccf6fa8df721de30.CopyToNotebookRequestBuilder
CopyToNotebook the copyToNotebook property
func (*OnenoteSectionItemRequestBuilder) CopyToSectionGroup ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CopyToSectionGroup() *i3d7002a5830e410a631889a32c956283a451ecd4b98e32c39d64998e9d3fcd87.CopyToSectionGroupRequestBuilder
CopyToSectionGroup the copyToSectionGroup property
func (*OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property sections for users
func (*OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformationWithRequestConfiguration delete navigation property sections for users
func (*OnenoteSectionItemRequestBuilder) CreateGetRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property sections in users
func (*OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *OnenoteSectionItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, requestConfiguration *OnenoteSectionItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformationWithRequestConfiguration update the navigation property sections in users
func (*OnenoteSectionItemRequestBuilder) Delete ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *OnenoteSectionItemRequestBuilderDeleteRequestConfiguration) error
Delete delete navigation property sections for users
func (*OnenoteSectionItemRequestBuilder) Get ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Get(ctx context.Context, requestConfiguration *OnenoteSectionItemRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, error)
Get the sections in the section group. Read-only. Nullable.
func (*OnenoteSectionItemRequestBuilder) Pages ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Pages() *i364b7d115e926a8d6dd12e2a57eca06e27e34cec79da1ad2228bbf04749f639a.PagesRequestBuilder
Pages the pages property
func (*OnenoteSectionItemRequestBuilder) PagesById ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) PagesById(id string) *i951ec0eea7285fb56b5978d2e83f30be17917daa2edaa99c9d6f5533dc8232d5.OnenotePageItemRequestBuilder
PagesById gets an item from the github.com/microsoftgraph/msgraph-sdk-go/.users.item.onenote.sectionGroups.item.sections.item.pages.item collection
func (*OnenoteSectionItemRequestBuilder) ParentNotebook ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) ParentNotebook() *i1a03214de0311f9b2b925b361927c75ad4e5ace7606d6822c54d52227560c97e.ParentNotebookRequestBuilder
ParentNotebook the parentNotebook property
func (*OnenoteSectionItemRequestBuilder) ParentSectionGroup ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) ParentSectionGroup() *ibaceb5a9714647bf058d5ee47723346a7c1e8ffc50b7298416c8916c89d64bd4.ParentSectionGroupRequestBuilder
ParentSectionGroup the parentSectionGroup property
func (*OnenoteSectionItemRequestBuilder) Patch ¶ added in v0.12.0
func (m *OnenoteSectionItemRequestBuilder) Patch(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OnenoteSectionable, requestConfiguration *OnenoteSectionItemRequestBuilderPatchRequestConfiguration) error
Patch update the navigation property sections in users
type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OnenoteSectionItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OnenoteSectionItemRequestBuilderGetQueryParameters ¶ added in v0.12.0
type OnenoteSectionItemRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
OnenoteSectionItemRequestBuilderGetQueryParameters the sections in the section group. Read-only. Nullable.
type OnenoteSectionItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *OnenoteSectionItemRequestBuilderGetQueryParameters
}
OnenoteSectionItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OnenoteSectionItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type OnenoteSectionItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OnenoteSectionItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.