Documentation
¶
Index ¶
- type OnenotePageRequestBuilder
- func (m *OnenotePageRequestBuilder) Content() ...
- func (m *OnenotePageRequestBuilder) CopyToSection() ...
- func (m *OnenotePageRequestBuilder) CreateDeleteRequestInformation(options *OnenotePageRequestBuilderDeleteOptions) (...)
- func (m *OnenotePageRequestBuilder) CreateGetRequestInformation(options *OnenotePageRequestBuilderGetOptions) (...)
- func (m *OnenotePageRequestBuilder) CreatePatchRequestInformation(options *OnenotePageRequestBuilderPatchOptions) (...)
- func (m *OnenotePageRequestBuilder) Delete(options *OnenotePageRequestBuilderDeleteOptions) error
- func (m *OnenotePageRequestBuilder) Get(options *OnenotePageRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.OnenotePage, ...)
- func (m *OnenotePageRequestBuilder) OnenotePatchContent() ...
- func (m *OnenotePageRequestBuilder) ParentNotebook() ...
- func (m *OnenotePageRequestBuilder) ParentSection() ...
- func (m *OnenotePageRequestBuilder) Patch(options *OnenotePageRequestBuilderPatchOptions) error
- func (m *OnenotePageRequestBuilder) Preview() ...
- type OnenotePageRequestBuilderDeleteOptions
- type OnenotePageRequestBuilderGetOptions
- type OnenotePageRequestBuilderGetQueryParameters
- type OnenotePageRequestBuilderPatchOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OnenotePageRequestBuilder ¶
type OnenotePageRequestBuilder struct {
// contains filtered or unexported fields
}
Builds and executes requests for operations under \users\{user-id}\onenote\sections\{onenoteSection-id}\pages\{onenotePage-id}
func NewOnenotePageRequestBuilder ¶
func NewOnenotePageRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *OnenotePageRequestBuilder
Instantiates a new OnenotePageRequestBuilder and sets the default values. Parameters:
- rawUrl : The raw URL to use for the request builder.
- requestAdapter : The request adapter to use to execute the requests.
func NewOnenotePageRequestBuilderInternal ¶
func NewOnenotePageRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *OnenotePageRequestBuilder
Instantiates a new OnenotePageRequestBuilder and sets the default values. Parameters:
- pathParameters : Path parameters for the request
- requestAdapter : The request adapter to use to execute the requests.
func (*OnenotePageRequestBuilder) CopyToSection ¶
func (*OnenotePageRequestBuilder) CreateDeleteRequestInformation ¶
func (m *OnenotePageRequestBuilder) CreateDeleteRequestInformation(options *OnenotePageRequestBuilderDeleteOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The collection of pages in the section. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenotePageRequestBuilder) CreateGetRequestInformation ¶
func (m *OnenotePageRequestBuilder) CreateGetRequestInformation(options *OnenotePageRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The collection of pages in the section. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenotePageRequestBuilder) CreatePatchRequestInformation ¶
func (m *OnenotePageRequestBuilder) CreatePatchRequestInformation(options *OnenotePageRequestBuilderPatchOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The collection of pages in the section. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenotePageRequestBuilder) Delete ¶
func (m *OnenotePageRequestBuilder) Delete(options *OnenotePageRequestBuilderDeleteOptions) error
The collection of pages in the section. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenotePageRequestBuilder) Get ¶
func (m *OnenotePageRequestBuilder) Get(options *OnenotePageRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.OnenotePage, error)
The collection of pages in the section. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenotePageRequestBuilder) OnenotePatchContent ¶
func (m *OnenotePageRequestBuilder) OnenotePatchContent() *i72d765e94eceb75c3cee9022529e06d7864b962d2570b0fd2bec67012250756a.OnenotePatchContentRequestBuilder
func (*OnenotePageRequestBuilder) ParentNotebook ¶
func (m *OnenotePageRequestBuilder) ParentNotebook() *ia32a0906dc3b88d5de9093a53dcfe352ee0c8f51547fe24d21039e86dd9c9c2e.ParentNotebookRequestBuilder
func (*OnenotePageRequestBuilder) ParentSection ¶
func (*OnenotePageRequestBuilder) Patch ¶
func (m *OnenotePageRequestBuilder) Patch(options *OnenotePageRequestBuilderPatchOptions) error
The collection of pages in the section. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenotePageRequestBuilder) Preview ¶
func (m *OnenotePageRequestBuilder) Preview() *i87ef1351bf76528386adcff2cd22c9751e1db744001b7c477054bbb713e35c1b.PreviewRequestBuilder
Builds and executes requests for operations under \users\{user-id}\onenote\sections\{onenoteSection-id}\pages\{onenotePage-id}\microsoft.graph.preview()
type OnenotePageRequestBuilderDeleteOptions ¶
type OnenotePageRequestBuilderDeleteOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Delete
type OnenotePageRequestBuilderGetOptions ¶
type OnenotePageRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *OnenotePageRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Get
type OnenotePageRequestBuilderGetQueryParameters ¶
type OnenotePageRequestBuilderGetQueryParameters struct {
ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.QueryParametersBase
// Expand related entities
Expand []string
// Select properties to be returned
Select_escaped []string
}
The collection of pages in the section. Read-only. Nullable.
type OnenotePageRequestBuilderPatchOptions ¶
type OnenotePageRequestBuilderPatchOptions struct {
//
Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.OnenotePage
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Patch