Documentation
¶
Index ¶
- type OutlookCategoryItemRequestBuilder
- func (m *OutlookCategoryItemRequestBuilder) CreateDeleteRequestInformation(ctx context.Context, ...) (...)
- func (m *OutlookCategoryItemRequestBuilder) CreateGetRequestInformation(ctx context.Context, ...) (...)
- func (m *OutlookCategoryItemRequestBuilder) CreatePatchRequestInformation(ctx context.Context, ...) (...)
- func (m *OutlookCategoryItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *OutlookCategoryItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *OutlookCategoryItemRequestBuilder) Patch(ctx context.Context, ...) (...)
- type OutlookCategoryItemRequestBuilderDeleteRequestConfiguration
- type OutlookCategoryItemRequestBuilderGetQueryParameters
- type OutlookCategoryItemRequestBuilderGetRequestConfiguration
- type OutlookCategoryItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OutlookCategoryItemRequestBuilder ¶ added in v0.12.0
type OutlookCategoryItemRequestBuilder struct {
// contains filtered or unexported fields
}
OutlookCategoryItemRequestBuilder provides operations to manage the masterCategories property of the microsoft.graph.outlookUser entity.
func NewOutlookCategoryItemRequestBuilder ¶ added in v0.12.0
func NewOutlookCategoryItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OutlookCategoryItemRequestBuilder
NewOutlookCategoryItemRequestBuilder instantiates a new OutlookCategoryItemRequestBuilder and sets the default values.
func NewOutlookCategoryItemRequestBuilderInternal ¶ added in v0.12.0
func NewOutlookCategoryItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *OutlookCategoryItemRequestBuilder
NewOutlookCategoryItemRequestBuilderInternal instantiates a new OutlookCategoryItemRequestBuilder and sets the default values.
func (*OutlookCategoryItemRequestBuilder) CreateDeleteRequestInformation ¶ added in v0.12.0
func (m *OutlookCategoryItemRequestBuilder) CreateDeleteRequestInformation(ctx context.Context, requestConfiguration *OutlookCategoryItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property masterCategories for users
func (*OutlookCategoryItemRequestBuilder) CreateGetRequestInformation ¶ added in v0.12.0
func (m *OutlookCategoryItemRequestBuilder) CreateGetRequestInformation(ctx context.Context, requestConfiguration *OutlookCategoryItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation a list of categories defined for the user.
func (*OutlookCategoryItemRequestBuilder) CreatePatchRequestInformation ¶ added in v0.12.0
func (m *OutlookCategoryItemRequestBuilder) CreatePatchRequestInformation(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OutlookCategoryable, requestConfiguration *OutlookCategoryItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property masterCategories in users
func (*OutlookCategoryItemRequestBuilder) Delete ¶ added in v0.12.0
func (m *OutlookCategoryItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *OutlookCategoryItemRequestBuilderDeleteRequestConfiguration) error
Delete delete navigation property masterCategories for users
func (*OutlookCategoryItemRequestBuilder) Get ¶ added in v0.12.0
func (m *OutlookCategoryItemRequestBuilder) Get(ctx context.Context, requestConfiguration *OutlookCategoryItemRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OutlookCategoryable, error)
Get a list of categories defined for the user.
func (*OutlookCategoryItemRequestBuilder) Patch ¶ added in v0.12.0
func (m *OutlookCategoryItemRequestBuilder) Patch(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OutlookCategoryable, requestConfiguration *OutlookCategoryItemRequestBuilderPatchRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.OutlookCategoryable, error)
Patch update the navigation property masterCategories in users
type OutlookCategoryItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type OutlookCategoryItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OutlookCategoryItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OutlookCategoryItemRequestBuilderGetQueryParameters ¶ added in v0.12.0
type OutlookCategoryItemRequestBuilderGetQueryParameters struct {
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
OutlookCategoryItemRequestBuilderGetQueryParameters a list of categories defined for the user.
type OutlookCategoryItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type OutlookCategoryItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *OutlookCategoryItemRequestBuilderGetQueryParameters
}
OutlookCategoryItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type OutlookCategoryItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type OutlookCategoryItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
OutlookCategoryItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.