item

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ProfilePhotoItemRequestBuilder added in v0.12.0

type ProfilePhotoItemRequestBuilder struct {
	// contains filtered or unexported fields
}

ProfilePhotoItemRequestBuilder provides operations to manage the photos property of the microsoft.graph.user entity.

func NewProfilePhotoItemRequestBuilder added in v0.12.0

NewProfilePhotoItemRequestBuilder instantiates a new ProfilePhotoItemRequestBuilder and sets the default values.

func NewProfilePhotoItemRequestBuilderInternal added in v0.12.0

func NewProfilePhotoItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ProfilePhotoItemRequestBuilder

NewProfilePhotoItemRequestBuilderInternal instantiates a new ProfilePhotoItemRequestBuilder and sets the default values.

func (*ProfilePhotoItemRequestBuilder) Content added in v0.12.0

Content the Content property

func (*ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformation added in v0.12.0

CreateDeleteRequestInformation delete navigation property photos for users

func (*ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration added in v0.22.0

CreateDeleteRequestInformationWithRequestConfiguration delete navigation property photos for users

func (*ProfilePhotoItemRequestBuilder) CreateGetRequestInformation added in v0.12.0

CreateGetRequestInformation read-only. Nullable.

func (*ProfilePhotoItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration added in v0.22.0

CreateGetRequestInformationWithRequestConfiguration read-only. Nullable.

func (*ProfilePhotoItemRequestBuilder) CreatePatchRequestInformation added in v0.12.0

CreatePatchRequestInformation update the navigation property photos in users

func (*ProfilePhotoItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration added in v0.22.0

CreatePatchRequestInformationWithRequestConfiguration update the navigation property photos in users

func (*ProfilePhotoItemRequestBuilder) Delete added in v0.12.0

Delete delete navigation property photos for users

func (*ProfilePhotoItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler added in v0.22.0

DeleteWithRequestConfigurationAndResponseHandler delete navigation property photos for users

func (*ProfilePhotoItemRequestBuilder) Get added in v0.12.0

Get read-only. Nullable.

func (*ProfilePhotoItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler added in v0.22.0

GetWithRequestConfigurationAndResponseHandler read-only. Nullable.

func (*ProfilePhotoItemRequestBuilder) Patch added in v0.12.0

Patch update the navigation property photos in users

func (*ProfilePhotoItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler added in v0.22.0

PatchWithRequestConfigurationAndResponseHandler update the navigation property photos in users

type ProfilePhotoItemRequestBuilderDeleteRequestConfiguration added in v0.22.0

type ProfilePhotoItemRequestBuilderDeleteRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

ProfilePhotoItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type ProfilePhotoItemRequestBuilderGetQueryParameters added in v0.12.0

type ProfilePhotoItemRequestBuilderGetQueryParameters struct {
	// Select properties to be returned
	Select []string `uriparametername:"%24select"`
}

ProfilePhotoItemRequestBuilderGetQueryParameters read-only. Nullable.

type ProfilePhotoItemRequestBuilderGetRequestConfiguration added in v0.22.0

type ProfilePhotoItemRequestBuilderGetRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
	// Request query parameters
	QueryParameters *ProfilePhotoItemRequestBuilderGetQueryParameters
}

ProfilePhotoItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

type ProfilePhotoItemRequestBuilderPatchRequestConfiguration added in v0.22.0

type ProfilePhotoItemRequestBuilderPatchRequestConfiguration struct {
	// Request headers
	Headers map[string]string
	// Request options
	Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}

ProfilePhotoItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.

Directories

Path Synopsis

Jump to