workday_intl

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type WorkDay_IntlRequestBody

type WorkDay_IntlRequestBody struct {
	// contains filtered or unexported fields
}

WorkDay_IntlRequestBody

func NewWorkDay_IntlRequestBody

func NewWorkDay_IntlRequestBody() *WorkDay_IntlRequestBody

NewWorkDay_IntlRequestBody instantiates a new workDay_IntlRequestBody and sets the default values.

func (*WorkDay_IntlRequestBody) GetAdditionalData

func (m *WorkDay_IntlRequestBody) GetAdditionalData() map[string]interface{}

GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*WorkDay_IntlRequestBody) GetDays

GetDays gets the days property value.

func (*WorkDay_IntlRequestBody) GetFieldDeserializers

GetFieldDeserializers the deserialization information for the current model

func (*WorkDay_IntlRequestBody) GetHolidays

GetHolidays gets the holidays property value.

func (*WorkDay_IntlRequestBody) GetStartDate

GetStartDate gets the startDate property value.

func (*WorkDay_IntlRequestBody) GetWeekend

GetWeekend gets the weekend property value.

func (*WorkDay_IntlRequestBody) IsNil

func (m *WorkDay_IntlRequestBody) IsNil() bool

func (*WorkDay_IntlRequestBody) Serialize

Serialize serializes information the current object

func (*WorkDay_IntlRequestBody) SetAdditionalData

func (m *WorkDay_IntlRequestBody) SetAdditionalData(value map[string]interface{})

SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*WorkDay_IntlRequestBody) SetDays

SetDays sets the days property value.

func (*WorkDay_IntlRequestBody) SetHolidays

SetHolidays sets the holidays property value.

func (*WorkDay_IntlRequestBody) SetStartDate

SetStartDate sets the startDate property value.

func (*WorkDay_IntlRequestBody) SetWeekend

SetWeekend sets the weekend property value.

type WorkDay_IntlRequestBuilder

type WorkDay_IntlRequestBuilder struct {
	// contains filtered or unexported fields
}

WorkDay_IntlRequestBuilder builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\functions\microsoft.graph.workDay_Intl

func NewWorkDay_IntlRequestBuilder

NewWorkDay_IntlRequestBuilder instantiates a new WorkDay_IntlRequestBuilder and sets the default values.

func NewWorkDay_IntlRequestBuilderInternal

func NewWorkDay_IntlRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *WorkDay_IntlRequestBuilder

NewWorkDay_IntlRequestBuilderInternal instantiates a new WorkDay_IntlRequestBuilder and sets the default values.

func (*WorkDay_IntlRequestBuilder) CreatePostRequestInformation

CreatePostRequestInformation invoke action workDay_Intl

func (*WorkDay_IntlRequestBuilder) Post

Post invoke action workDay_Intl

type WorkDay_IntlRequestBuilderPostOptions

type WorkDay_IntlRequestBuilderPostOptions struct {
	//
	Body *WorkDay_IntlRequestBody
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

WorkDay_IntlRequestBuilderPostOptions options for Post

type WorkDay_IntlResponse

type WorkDay_IntlResponse struct {
	// contains filtered or unexported fields
}

WorkDay_IntlResponse union type wrapper for classes workbookFunctionResult

func NewWorkDay_IntlResponse

func NewWorkDay_IntlResponse() *WorkDay_IntlResponse

NewWorkDay_IntlResponse instantiates a new workDay_IntlResponse and sets the default values.

func (*WorkDay_IntlResponse) GetAdditionalData

func (m *WorkDay_IntlResponse) GetAdditionalData() map[string]interface{}

GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*WorkDay_IntlResponse) GetFieldDeserializers

GetFieldDeserializers the deserialization information for the current model

func (*WorkDay_IntlResponse) GetWorkbookFunctionResult

GetWorkbookFunctionResult gets the workbookFunctionResult property value. Union type representation for type workbookFunctionResult

func (*WorkDay_IntlResponse) IsNil

func (m *WorkDay_IntlResponse) IsNil() bool

func (*WorkDay_IntlResponse) Serialize

Serialize serializes information the current object

func (*WorkDay_IntlResponse) SetAdditionalData

func (m *WorkDay_IntlResponse) SetAdditionalData(value map[string]interface{})

SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*WorkDay_IntlResponse) SetWorkbookFunctionResult

SetWorkbookFunctionResult sets the workbookFunctionResult property value. Union type representation for type workbookFunctionResult

Jump to