rows

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 4, 2021 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RowsRequestBuilder

type RowsRequestBuilder struct {
	// contains filtered or unexported fields
}

Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows

func NewRowsRequestBuilder

Instantiates a new RowsRequestBuilder and sets the default values. Parameters:

  • rawUrl : The raw URL to use for the request builder.
  • requestAdapter : The request adapter to use to execute the requests.

func NewRowsRequestBuilderInternal

func NewRowsRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *RowsRequestBuilder

Instantiates a new RowsRequestBuilder and sets the default values. Parameters:

  • pathParameters : Path parameters for the request
  • requestAdapter : The request adapter to use to execute the requests.

func (*RowsRequestBuilder) Count

Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows\microsoft.graph.count()

func (*RowsRequestBuilder) CreateGetRequestInformation

Represents a collection of all the rows in the table. Read-only. Parameters:

  • options : Options for the request

func (*RowsRequestBuilder) CreatePostRequestInformation

Represents a collection of all the rows in the table. Read-only. Parameters:

  • options : Options for the request

func (*RowsRequestBuilder) Get

Represents a collection of all the rows in the table. Read-only. Parameters:

  • options : Options for the request

func (*RowsRequestBuilder) ItemAtWithIndex

Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows\microsoft.graph.itemAt(index={index}) Parameters:

  • index : Usage: index={index}

func (*RowsRequestBuilder) Post

Represents a collection of all the rows in the table. Read-only. Parameters:

  • options : Options for the request

type RowsRequestBuilderGetOptions

type RowsRequestBuilderGetOptions struct {
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Request query parameters
	Q *RowsRequestBuilderGetQueryParameters
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

Options for Get

type RowsRequestBuilderGetQueryParameters

type RowsRequestBuilderGetQueryParameters struct {
	ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.QueryParametersBase
	// Include count of items
	Count *bool
	// Expand related entities
	Expand []string
	// Filter items by property values
	Filter *string
	// Order items by property values
	Orderby []string
	// Search items by search phrases
	Search *string
	// Select properties to be returned
	Select_escaped []string
	// Skip the first n items
	Skip *int32
	// Show only the first n items
	Top *int32
}

Represents a collection of all the rows in the table. Read-only.

type RowsRequestBuilderPostOptions

type RowsRequestBuilderPostOptions struct {
	//
	Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow
	// Request headers
	H map[string]string
	// Request options
	O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
	// Response handler to use in place of the default response handling provided by the core service
	ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}

Options for Post

type RowsResponse

type RowsResponse struct {
	// contains filtered or unexported fields
}

func NewRowsResponse

func NewRowsResponse() *RowsResponse

Instantiates a new rowsResponse and sets the default values.

func (*RowsResponse) GetAdditionalData

func (m *RowsResponse) GetAdditionalData() map[string]interface{}

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

func (*RowsResponse) GetFieldDeserializers

The deserialization information for the current model

func (m *RowsResponse) GetNextLink() *string

Gets the nextLink property value.

func (*RowsResponse) GetValue

Gets the value property value.

func (*RowsResponse) IsNil

func (m *RowsResponse) IsNil() bool

func (*RowsResponse) Serialize

Serializes information the current object Parameters:

  • writer : Serialization writer to use to serialize this model

func (*RowsResponse) SetAdditionalData

func (m *RowsResponse) SetAdditionalData(value map[string]interface{})

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. Parameters:

  • value : Value to set for the AdditionalData property.
func (m *RowsResponse) SetNextLink(value *string)

Sets the nextLink property value. Parameters:

  • value : Value to set for the nextLink property.

func (*RowsResponse) SetValue

Sets the value property value. Parameters:

  • value : Value to set for the value property.

Directories

Path Synopsis

Jump to