Documentation
¶
Index ¶
- type WorkbookTableRowRequestBuilder
- func (m *WorkbookTableRowRequestBuilder) CreateDeleteRequestInformation(options *WorkbookTableRowRequestBuilderDeleteOptions) (...)
- func (m *WorkbookTableRowRequestBuilder) CreateGetRequestInformation(options *WorkbookTableRowRequestBuilderGetOptions) (...)
- func (m *WorkbookTableRowRequestBuilder) CreatePatchRequestInformation(options *WorkbookTableRowRequestBuilderPatchOptions) (...)
- func (m *WorkbookTableRowRequestBuilder) Delete(options *WorkbookTableRowRequestBuilderDeleteOptions) error
- func (m *WorkbookTableRowRequestBuilder) Get(options *WorkbookTableRowRequestBuilderGetOptions) (...)
- func (m *WorkbookTableRowRequestBuilder) Patch(options *WorkbookTableRowRequestBuilderPatchOptions) error
- func (m *WorkbookTableRowRequestBuilder) Range_escaped() ...
- type WorkbookTableRowRequestBuilderDeleteOptions
- type WorkbookTableRowRequestBuilderGetOptions
- type WorkbookTableRowRequestBuilderGetQueryParameters
- type WorkbookTableRowRequestBuilderPatchOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type WorkbookTableRowRequestBuilder ¶
type WorkbookTableRowRequestBuilder struct {
// contains filtered or unexported fields
}
Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows\{workbookTableRow-id}
func NewWorkbookTableRowRequestBuilder ¶
func NewWorkbookTableRowRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *WorkbookTableRowRequestBuilder
Instantiates a new WorkbookTableRowRequestBuilder and sets the default values. Parameters:
- rawUrl : The raw URL to use for the request builder.
- requestAdapter : The request adapter to use to execute the requests.
func NewWorkbookTableRowRequestBuilderInternal ¶
func NewWorkbookTableRowRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *WorkbookTableRowRequestBuilder
Instantiates a new WorkbookTableRowRequestBuilder and sets the default values. Parameters:
- pathParameters : Path parameters for the request
- requestAdapter : The request adapter to use to execute the requests.
func (*WorkbookTableRowRequestBuilder) CreateDeleteRequestInformation ¶
func (m *WorkbookTableRowRequestBuilder) CreateDeleteRequestInformation(options *WorkbookTableRowRequestBuilderDeleteOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*WorkbookTableRowRequestBuilder) CreateGetRequestInformation ¶
func (m *WorkbookTableRowRequestBuilder) CreateGetRequestInformation(options *WorkbookTableRowRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*WorkbookTableRowRequestBuilder) CreatePatchRequestInformation ¶
func (m *WorkbookTableRowRequestBuilder) CreatePatchRequestInformation(options *WorkbookTableRowRequestBuilderPatchOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*WorkbookTableRowRequestBuilder) Delete ¶
func (m *WorkbookTableRowRequestBuilder) Delete(options *WorkbookTableRowRequestBuilderDeleteOptions) error
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*WorkbookTableRowRequestBuilder) Get ¶
func (m *WorkbookTableRowRequestBuilder) Get(options *WorkbookTableRowRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*WorkbookTableRowRequestBuilder) Patch ¶
func (m *WorkbookTableRowRequestBuilder) Patch(options *WorkbookTableRowRequestBuilderPatchOptions) error
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*WorkbookTableRowRequestBuilder) Range_escaped ¶
func (m *WorkbookTableRowRequestBuilder) Range_escaped() *i25ef8d90747b2ebd78f6cfd15905a0589f3662d6db5494114c418aa63ed77015.RangeRequestBuilder
Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows\{workbookTableRow-id}\microsoft.graph.range()
type WorkbookTableRowRequestBuilderDeleteOptions ¶
type WorkbookTableRowRequestBuilderDeleteOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Delete
type WorkbookTableRowRequestBuilderGetOptions ¶
type WorkbookTableRowRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *WorkbookTableRowRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Get
type WorkbookTableRowRequestBuilderGetQueryParameters ¶
type WorkbookTableRowRequestBuilderGetQueryParameters struct {
ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.QueryParametersBase
// Expand related entities
Expand []string
// Select properties to be returned
Select_escaped []string
}
Represents a collection of all the rows in the table. Read-only.
type WorkbookTableRowRequestBuilderPatchOptions ¶
type WorkbookTableRowRequestBuilderPatchOptions struct {
//
Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Patch