Documentation
¶
Index ¶
- type OnenoteOperationRequestBuilder
- func (m *OnenoteOperationRequestBuilder) CreateDeleteRequestInformation(options *OnenoteOperationRequestBuilderDeleteOptions) (...)
- func (m *OnenoteOperationRequestBuilder) CreateGetRequestInformation(options *OnenoteOperationRequestBuilderGetOptions) (...)
- func (m *OnenoteOperationRequestBuilder) CreatePatchRequestInformation(options *OnenoteOperationRequestBuilderPatchOptions) (...)
- func (m *OnenoteOperationRequestBuilder) Delete(options *OnenoteOperationRequestBuilderDeleteOptions) error
- func (m *OnenoteOperationRequestBuilder) Get(options *OnenoteOperationRequestBuilderGetOptions) (...)
- func (m *OnenoteOperationRequestBuilder) Patch(options *OnenoteOperationRequestBuilderPatchOptions) error
- type OnenoteOperationRequestBuilderDeleteOptions
- type OnenoteOperationRequestBuilderGetOptions
- type OnenoteOperationRequestBuilderGetQueryParameters
- type OnenoteOperationRequestBuilderPatchOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OnenoteOperationRequestBuilder ¶
type OnenoteOperationRequestBuilder struct {
// contains filtered or unexported fields
}
Builds and executes requests for operations under \groups\{group-id}\onenote\operations\{onenoteOperation-id}
func NewOnenoteOperationRequestBuilder ¶
func NewOnenoteOperationRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *OnenoteOperationRequestBuilder
Instantiates a new OnenoteOperationRequestBuilder and sets the default values. Parameters:
- rawUrl : The raw URL to use for the request builder.
- requestAdapter : The request adapter to use to execute the requests.
func NewOnenoteOperationRequestBuilderInternal ¶
func NewOnenoteOperationRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *OnenoteOperationRequestBuilder
Instantiates a new OnenoteOperationRequestBuilder and sets the default values. Parameters:
- pathParameters : Path parameters for the request
- requestAdapter : The request adapter to use to execute the requests.
func (*OnenoteOperationRequestBuilder) CreateDeleteRequestInformation ¶
func (m *OnenoteOperationRequestBuilder) CreateDeleteRequestInformation(options *OnenoteOperationRequestBuilderDeleteOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenoteOperationRequestBuilder) CreateGetRequestInformation ¶
func (m *OnenoteOperationRequestBuilder) CreateGetRequestInformation(options *OnenoteOperationRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenoteOperationRequestBuilder) CreatePatchRequestInformation ¶
func (m *OnenoteOperationRequestBuilder) CreatePatchRequestInformation(options *OnenoteOperationRequestBuilderPatchOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenoteOperationRequestBuilder) Delete ¶
func (m *OnenoteOperationRequestBuilder) Delete(options *OnenoteOperationRequestBuilderDeleteOptions) error
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenoteOperationRequestBuilder) Get ¶
func (m *OnenoteOperationRequestBuilder) Get(options *OnenoteOperationRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.OnenoteOperation, error)
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. Parameters:
- options : Options for the request
func (*OnenoteOperationRequestBuilder) Patch ¶
func (m *OnenoteOperationRequestBuilder) Patch(options *OnenoteOperationRequestBuilderPatchOptions) error
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. Parameters:
- options : Options for the request
type OnenoteOperationRequestBuilderDeleteOptions ¶
type OnenoteOperationRequestBuilderDeleteOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Delete
type OnenoteOperationRequestBuilderGetOptions ¶
type OnenoteOperationRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *OnenoteOperationRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Get
type OnenoteOperationRequestBuilderGetQueryParameters ¶
type OnenoteOperationRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string
// Select properties to be returned
Select_escaped []string
}
The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable.
type OnenoteOperationRequestBuilderPatchOptions ¶
type OnenoteOperationRequestBuilderPatchOptions struct {
//
Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.OnenoteOperation
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Patch