Documentation
¶
Index ¶
- type AttachmentItemRequestBuilder
- func (m *AttachmentItemRequestBuilder) CreateDeleteRequestInformation() (...)
- func (m *AttachmentItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *AttachmentItemRequestBuilderDeleteRequestConfiguration) (...)
- func (m *AttachmentItemRequestBuilder) CreateGetRequestInformation() (...)
- func (m *AttachmentItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *AttachmentItemRequestBuilderGetRequestConfiguration) (...)
- func (m *AttachmentItemRequestBuilder) CreatePatchRequestInformation(...) (...)
- func (m *AttachmentItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(...) (...)
- func (m *AttachmentItemRequestBuilder) Delete(ctx context.Context, ...) error
- func (m *AttachmentItemRequestBuilder) Get(ctx context.Context, ...) (...)
- func (m *AttachmentItemRequestBuilder) Patch(ctx context.Context, ...) error
- type AttachmentItemRequestBuilderDeleteRequestConfiguration
- type AttachmentItemRequestBuilderGetQueryParameters
- type AttachmentItemRequestBuilderGetRequestConfiguration
- type AttachmentItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AttachmentItemRequestBuilder ¶
type AttachmentItemRequestBuilder struct {
// contains filtered or unexported fields
}
AttachmentItemRequestBuilder provides operations to manage the attachments property of the microsoft.graph.post entity.
func NewAttachmentItemRequestBuilder ¶
func NewAttachmentItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AttachmentItemRequestBuilder
NewAttachmentItemRequestBuilder instantiates a new AttachmentItemRequestBuilder and sets the default values.
func NewAttachmentItemRequestBuilderInternal ¶
func NewAttachmentItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *AttachmentItemRequestBuilder
NewAttachmentItemRequestBuilderInternal instantiates a new AttachmentItemRequestBuilder and sets the default values.
func (*AttachmentItemRequestBuilder) CreateDeleteRequestInformation ¶
func (m *AttachmentItemRequestBuilder) CreateDeleteRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property attachments for groups
func (*AttachmentItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *AttachmentItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *AttachmentItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformationWithRequestConfiguration delete navigation property attachments for groups
func (*AttachmentItemRequestBuilder) CreateGetRequestInformation ¶
func (m *AttachmentItemRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation read-only. Nullable. Supports $expand.
func (*AttachmentItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *AttachmentItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *AttachmentItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration read-only. Nullable. Supports $expand.
func (*AttachmentItemRequestBuilder) CreatePatchRequestInformation ¶
func (m *AttachmentItemRequestBuilder) CreatePatchRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.Attachmentable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property attachments in groups
func (*AttachmentItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *AttachmentItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.Attachmentable, requestConfiguration *AttachmentItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformationWithRequestConfiguration update the navigation property attachments in groups
func (*AttachmentItemRequestBuilder) Delete ¶
func (m *AttachmentItemRequestBuilder) Delete(ctx context.Context, requestConfiguration *AttachmentItemRequestBuilderDeleteRequestConfiguration) error
Delete delete navigation property attachments for groups
func (*AttachmentItemRequestBuilder) Get ¶
func (m *AttachmentItemRequestBuilder) Get(ctx context.Context, requestConfiguration *AttachmentItemRequestBuilderGetRequestConfiguration) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.Attachmentable, error)
Get read-only. Nullable. Supports $expand.
func (*AttachmentItemRequestBuilder) Patch ¶
func (m *AttachmentItemRequestBuilder) Patch(ctx context.Context, body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.Attachmentable, requestConfiguration *AttachmentItemRequestBuilderPatchRequestConfiguration) error
Patch update the navigation property attachments in groups
type AttachmentItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type AttachmentItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
AttachmentItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type AttachmentItemRequestBuilderGetQueryParameters ¶
type AttachmentItemRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string `uriparametername:"%24expand"`
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
AttachmentItemRequestBuilderGetQueryParameters read-only. Nullable. Supports $expand.
type AttachmentItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type AttachmentItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *AttachmentItemRequestBuilderGetQueryParameters
}
AttachmentItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type AttachmentItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type AttachmentItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
AttachmentItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.