Documentation
¶
Index ¶
- type AttachmentRequestBuilder
- func (m *AttachmentRequestBuilder) CreateDeleteRequestInformation(options *AttachmentRequestBuilderDeleteOptions) (...)
- func (m *AttachmentRequestBuilder) CreateGetRequestInformation(options *AttachmentRequestBuilderGetOptions) (...)
- func (m *AttachmentRequestBuilder) CreatePatchRequestInformation(options *AttachmentRequestBuilderPatchOptions) (...)
- func (m *AttachmentRequestBuilder) Delete(options *AttachmentRequestBuilderDeleteOptions) error
- func (m *AttachmentRequestBuilder) Get(options *AttachmentRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.Attachment, ...)
- func (m *AttachmentRequestBuilder) Patch(options *AttachmentRequestBuilderPatchOptions) error
- type AttachmentRequestBuilderDeleteOptions
- type AttachmentRequestBuilderGetOptions
- type AttachmentRequestBuilderGetQueryParameters
- type AttachmentRequestBuilderPatchOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AttachmentRequestBuilder ¶
type AttachmentRequestBuilder struct {
// contains filtered or unexported fields
}
AttachmentRequestBuilder builds and executes requests for operations under \me\calendar\events\{event-id}\attachments\{attachment-id}
func NewAttachmentRequestBuilder ¶
func NewAttachmentRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *AttachmentRequestBuilder
NewAttachmentRequestBuilder instantiates a new AttachmentRequestBuilder and sets the default values.
func NewAttachmentRequestBuilderInternal ¶
func NewAttachmentRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *AttachmentRequestBuilder
NewAttachmentRequestBuilderInternal instantiates a new AttachmentRequestBuilder and sets the default values.
func (*AttachmentRequestBuilder) CreateDeleteRequestInformation ¶
func (m *AttachmentRequestBuilder) CreateDeleteRequestInformation(options *AttachmentRequestBuilderDeleteOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
CreateDeleteRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentRequestBuilder) CreateGetRequestInformation ¶
func (m *AttachmentRequestBuilder) CreateGetRequestInformation(options *AttachmentRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
CreateGetRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentRequestBuilder) CreatePatchRequestInformation ¶
func (m *AttachmentRequestBuilder) CreatePatchRequestInformation(options *AttachmentRequestBuilderPatchOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
CreatePatchRequestInformation the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentRequestBuilder) Delete ¶
func (m *AttachmentRequestBuilder) Delete(options *AttachmentRequestBuilderDeleteOptions) error
Delete the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentRequestBuilder) Get ¶
func (m *AttachmentRequestBuilder) Get(options *AttachmentRequestBuilderGetOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.Attachment, error)
Get the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
func (*AttachmentRequestBuilder) Patch ¶
func (m *AttachmentRequestBuilder) Patch(options *AttachmentRequestBuilderPatchOptions) error
Patch the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
type AttachmentRequestBuilderDeleteOptions ¶
type AttachmentRequestBuilderDeleteOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
AttachmentRequestBuilderDeleteOptions options for Delete
type AttachmentRequestBuilderGetOptions ¶
type AttachmentRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *AttachmentRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
AttachmentRequestBuilderGetOptions options for Get
type AttachmentRequestBuilderGetQueryParameters ¶
type AttachmentRequestBuilderGetQueryParameters struct {
// Expand related entities
Expand []string
// Select properties to be returned
Select []string
}
AttachmentRequestBuilderGetQueryParameters the collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
type AttachmentRequestBuilderPatchOptions ¶
type AttachmentRequestBuilderPatchOptions struct {
//
Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.Attachment
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
AttachmentRequestBuilderPatchOptions options for Patch