Documentation
¶
Index ¶
- type BaseTypesRequestBuilder
- func (m *BaseTypesRequestBuilder) AddCopy() ...
- func (m *BaseTypesRequestBuilder) CreateGetRequestInformation(options *BaseTypesRequestBuilderGetOptions) (...)
- func (m *BaseTypesRequestBuilder) Get(options *BaseTypesRequestBuilderGetOptions) (*BaseTypesResponse, error)
- func (m *BaseTypesRequestBuilder) Ref() ...
- type BaseTypesRequestBuilderGetOptions
- type BaseTypesRequestBuilderGetQueryParameters
- type BaseTypesResponse
- func (m *BaseTypesResponse) GetAdditionalData() map[string]interface{}
- func (m *BaseTypesResponse) GetFieldDeserializers() map[string]func(interface{}, ...) error
- func (m *BaseTypesResponse) GetNextLink() *string
- func (m *BaseTypesResponse) GetValue() ...
- func (m *BaseTypesResponse) IsNil() bool
- func (m *BaseTypesResponse) Serialize(...) error
- func (m *BaseTypesResponse) SetAdditionalData(value map[string]interface{})
- func (m *BaseTypesResponse) SetNextLink(value *string)
- func (m *BaseTypesResponse) SetValue(...)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BaseTypesRequestBuilder ¶
type BaseTypesRequestBuilder struct {
// contains filtered or unexported fields
}
BaseTypesRequestBuilder builds and executes requests for operations under \shares\{sharedDriveItem-id}\list\contentTypes\{contentType-id}\baseTypes
func NewBaseTypesRequestBuilder ¶
func NewBaseTypesRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *BaseTypesRequestBuilder
NewBaseTypesRequestBuilder instantiates a new BaseTypesRequestBuilder and sets the default values.
func NewBaseTypesRequestBuilderInternal ¶
func NewBaseTypesRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *BaseTypesRequestBuilder
NewBaseTypesRequestBuilderInternal instantiates a new BaseTypesRequestBuilder and sets the default values.
func (*BaseTypesRequestBuilder) CreateGetRequestInformation ¶
func (m *BaseTypesRequestBuilder) CreateGetRequestInformation(options *BaseTypesRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
CreateGetRequestInformation the collection of content types that are ancestors of this content type.
func (*BaseTypesRequestBuilder) Get ¶
func (m *BaseTypesRequestBuilder) Get(options *BaseTypesRequestBuilderGetOptions) (*BaseTypesResponse, error)
Get the collection of content types that are ancestors of this content type.
type BaseTypesRequestBuilderGetOptions ¶
type BaseTypesRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *BaseTypesRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
BaseTypesRequestBuilderGetOptions options for Get
type BaseTypesRequestBuilderGetQueryParameters ¶
type BaseTypesRequestBuilderGetQueryParameters struct {
// Include count of items
Count *bool
// Expand related entities
Expand []string
// Filter items by property values
Filter *string
// Order items by property values
Orderby []string
// Search items by search phrases
Search *string
// Select properties to be returned
Select []string
// Skip the first n items
Skip *int32
// Show only the first n items
Top *int32
}
BaseTypesRequestBuilderGetQueryParameters the collection of content types that are ancestors of this content type.
type BaseTypesResponse ¶
type BaseTypesResponse struct {
// contains filtered or unexported fields
}
BaseTypesResponse
func NewBaseTypesResponse ¶
func NewBaseTypesResponse() *BaseTypesResponse
NewBaseTypesResponse instantiates a new baseTypesResponse and sets the default values.
func (*BaseTypesResponse) GetAdditionalData ¶
func (m *BaseTypesResponse) GetAdditionalData() map[string]interface{}
GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (*BaseTypesResponse) GetFieldDeserializers ¶
func (m *BaseTypesResponse) GetFieldDeserializers() map[string]func(interface{}, i04eb5309aeaafadd28374d79c8471df9b267510b4dc2e3144c378c50f6fd7b55.ParseNode) error
GetFieldDeserializers the deserialization information for the current model
func (*BaseTypesResponse) GetNextLink ¶
func (m *BaseTypesResponse) GetNextLink() *string
GetNextLink gets the @odata.nextLink property value.
func (*BaseTypesResponse) GetValue ¶
func (m *BaseTypesResponse) GetValue() []i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.ContentType
GetValue gets the value property value.
func (*BaseTypesResponse) IsNil ¶
func (m *BaseTypesResponse) IsNil() bool
func (*BaseTypesResponse) Serialize ¶
func (m *BaseTypesResponse) Serialize(writer i04eb5309aeaafadd28374d79c8471df9b267510b4dc2e3144c378c50f6fd7b55.SerializationWriter) error
Serialize serializes information the current object
func (*BaseTypesResponse) SetAdditionalData ¶
func (m *BaseTypesResponse) SetAdditionalData(value map[string]interface{})
SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (*BaseTypesResponse) SetNextLink ¶
func (m *BaseTypesResponse) SetNextLink(value *string)
SetNextLink sets the @odata.nextLink property value.
func (*BaseTypesResponse) SetValue ¶
func (m *BaseTypesResponse) SetValue(value []i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.ContentType)
SetValue sets the value property value.