Documentation
¶
Index ¶
- type ProfilePhotoItemRequestBuilder
- func (m *ProfilePhotoItemRequestBuilder) Content() ...
- func (m *ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformation() (...)
- func (m *ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *ProfilePhotoItemRequestBuilderDeleteRequestConfiguration) (...)
- func (m *ProfilePhotoItemRequestBuilder) CreateGetRequestInformation() (...)
- func (m *ProfilePhotoItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *ProfilePhotoItemRequestBuilderGetRequestConfiguration) (...)
- func (m *ProfilePhotoItemRequestBuilder) CreatePatchRequestInformation(...) (...)
- func (m *ProfilePhotoItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(...) (...)
- func (m *ProfilePhotoItemRequestBuilder) Delete() error
- func (m *ProfilePhotoItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler(requestConfiguration *ProfilePhotoItemRequestBuilderDeleteRequestConfiguration, ...) error
- func (m *ProfilePhotoItemRequestBuilder) Get() (...)
- func (m *ProfilePhotoItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler(requestConfiguration *ProfilePhotoItemRequestBuilderGetRequestConfiguration, ...) (...)
- func (m *ProfilePhotoItemRequestBuilder) Patch(...) error
- func (m *ProfilePhotoItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler(...) error
- type ProfilePhotoItemRequestBuilderDeleteRequestConfiguration
- type ProfilePhotoItemRequestBuilderGetQueryParameters
- type ProfilePhotoItemRequestBuilderGetRequestConfiguration
- type ProfilePhotoItemRequestBuilderPatchRequestConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProfilePhotoItemRequestBuilder ¶ added in v0.12.0
type ProfilePhotoItemRequestBuilder struct {
// contains filtered or unexported fields
}
ProfilePhotoItemRequestBuilder provides operations to manage the photos property of the microsoft.graph.user entity.
func NewProfilePhotoItemRequestBuilder ¶ added in v0.12.0
func NewProfilePhotoItemRequestBuilder(rawUrl string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ProfilePhotoItemRequestBuilder
NewProfilePhotoItemRequestBuilder instantiates a new ProfilePhotoItemRequestBuilder and sets the default values.
func NewProfilePhotoItemRequestBuilderInternal ¶ added in v0.12.0
func NewProfilePhotoItemRequestBuilderInternal(pathParameters map[string]string, requestAdapter i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestAdapter) *ProfilePhotoItemRequestBuilder
NewProfilePhotoItemRequestBuilderInternal instantiates a new ProfilePhotoItemRequestBuilder and sets the default values.
func (*ProfilePhotoItemRequestBuilder) Content ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) Content() *i23e4001e509987b306ab55a39f125dfb03e832727c8c0609e81d4aef4a43a147.ContentRequestBuilder
Content the Content property
func (*ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformation ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformation delete navigation property photos for users
func (*ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *ProfilePhotoItemRequestBuilder) CreateDeleteRequestInformationWithRequestConfiguration(requestConfiguration *ProfilePhotoItemRequestBuilderDeleteRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateDeleteRequestInformationWithRequestConfiguration delete navigation property photos for users
func (*ProfilePhotoItemRequestBuilder) CreateGetRequestInformation ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) CreateGetRequestInformation() (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformation read-only. Nullable.
func (*ProfilePhotoItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *ProfilePhotoItemRequestBuilder) CreateGetRequestInformationWithRequestConfiguration(requestConfiguration *ProfilePhotoItemRequestBuilderGetRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreateGetRequestInformationWithRequestConfiguration read-only. Nullable.
func (*ProfilePhotoItemRequestBuilder) CreatePatchRequestInformation ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) CreatePatchRequestInformation(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ProfilePhotoable) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformation update the navigation property photos in users
func (*ProfilePhotoItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration ¶ added in v0.22.0
func (m *ProfilePhotoItemRequestBuilder) CreatePatchRequestInformationWithRequestConfiguration(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ProfilePhotoable, requestConfiguration *ProfilePhotoItemRequestBuilderPatchRequestConfiguration) (*i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestInformation, error)
CreatePatchRequestInformationWithRequestConfiguration update the navigation property photos in users
func (*ProfilePhotoItemRequestBuilder) Delete ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) Delete() error
Delete delete navigation property photos for users
func (*ProfilePhotoItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *ProfilePhotoItemRequestBuilder) DeleteWithRequestConfigurationAndResponseHandler(requestConfiguration *ProfilePhotoItemRequestBuilderDeleteRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) error
DeleteWithRequestConfigurationAndResponseHandler delete navigation property photos for users
func (*ProfilePhotoItemRequestBuilder) Get ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) Get() (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ProfilePhotoable, error)
Get read-only. Nullable.
func (*ProfilePhotoItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *ProfilePhotoItemRequestBuilder) GetWithRequestConfigurationAndResponseHandler(requestConfiguration *ProfilePhotoItemRequestBuilderGetRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) (iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ProfilePhotoable, error)
GetWithRequestConfigurationAndResponseHandler read-only. Nullable.
func (*ProfilePhotoItemRequestBuilder) Patch ¶ added in v0.12.0
func (m *ProfilePhotoItemRequestBuilder) Patch(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ProfilePhotoable) error
Patch update the navigation property photos in users
func (*ProfilePhotoItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler ¶ added in v0.22.0
func (m *ProfilePhotoItemRequestBuilder) PatchWithRequestConfigurationAndResponseHandler(body iadcd81124412c61e647227ecfc4449d8bba17de0380ddda76f641a29edf2b242.ProfilePhotoable, requestConfiguration *ProfilePhotoItemRequestBuilderPatchRequestConfiguration, responseHandler i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.ResponseHandler) error
PatchWithRequestConfigurationAndResponseHandler update the navigation property photos in users
type ProfilePhotoItemRequestBuilderDeleteRequestConfiguration ¶ added in v0.22.0
type ProfilePhotoItemRequestBuilderDeleteRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ProfilePhotoItemRequestBuilderDeleteRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ProfilePhotoItemRequestBuilderGetQueryParameters ¶ added in v0.12.0
type ProfilePhotoItemRequestBuilderGetQueryParameters struct {
// Select properties to be returned
Select []string `uriparametername:"%24select"`
}
ProfilePhotoItemRequestBuilderGetQueryParameters read-only. Nullable.
type ProfilePhotoItemRequestBuilderGetRequestConfiguration ¶ added in v0.22.0
type ProfilePhotoItemRequestBuilderGetRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
// Request query parameters
QueryParameters *ProfilePhotoItemRequestBuilderGetQueryParameters
}
ProfilePhotoItemRequestBuilderGetRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.
type ProfilePhotoItemRequestBuilderPatchRequestConfiguration ¶ added in v0.22.0
type ProfilePhotoItemRequestBuilderPatchRequestConfiguration struct {
// Request headers
Headers map[string]string
// Request options
Options []i2ae4187f7daee263371cb1c977df639813ab50ffa529013b7437480d1ec0158f.RequestOption
}
ProfilePhotoItemRequestBuilderPatchRequestConfiguration configuration for the request such as headers, query parameters, and middleware options.