Documentation
¶
Index ¶
- type RowsRequestBuilder
- func (m *RowsRequestBuilder) Add() ...
- func (m *RowsRequestBuilder) Count() ...
- func (m *RowsRequestBuilder) CreateGetRequestInformation(options *RowsRequestBuilderGetOptions) (...)
- func (m *RowsRequestBuilder) CreatePostRequestInformation(options *RowsRequestBuilderPostOptions) (...)
- func (m *RowsRequestBuilder) Get(options *RowsRequestBuilderGetOptions) (*RowsResponse, error)
- func (m *RowsRequestBuilder) ItemAtWithIndex(index *int32) ...
- func (m *RowsRequestBuilder) Post(options *RowsRequestBuilderPostOptions) (...)
- type RowsRequestBuilderGetOptions
- type RowsRequestBuilderGetQueryParameters
- type RowsRequestBuilderPostOptions
- type RowsResponse
- func (m *RowsResponse) GetAdditionalData() map[string]interface{}
- func (m *RowsResponse) GetFieldDeserializers() map[string]func(interface{}, ...) error
- func (m *RowsResponse) GetNextLink() *string
- func (m *RowsResponse) GetValue() ...
- func (m *RowsResponse) IsNil() bool
- func (m *RowsResponse) Serialize(...) error
- func (m *RowsResponse) SetAdditionalData(value map[string]interface{})
- func (m *RowsResponse) SetNextLink(value *string)
- func (m *RowsResponse) SetValue(...)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RowsRequestBuilder ¶
type RowsRequestBuilder struct {
// contains filtered or unexported fields
}
Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows
func NewRowsRequestBuilder ¶
func NewRowsRequestBuilder(rawUrl string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *RowsRequestBuilder
Instantiates a new RowsRequestBuilder and sets the default values. Parameters:
- rawUrl : The raw URL to use for the request builder.
- requestAdapter : The request adapter to use to execute the requests.
func NewRowsRequestBuilderInternal ¶
func NewRowsRequestBuilderInternal(pathParameters map[string]string, requestAdapter ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestAdapter) *RowsRequestBuilder
Instantiates a new RowsRequestBuilder and sets the default values. Parameters:
- pathParameters : Path parameters for the request
- requestAdapter : The request adapter to use to execute the requests.
func (*RowsRequestBuilder) Count ¶
func (m *RowsRequestBuilder) Count() *ie44e5e173cf42a7721e0aefa47d7005d1abc06aee64c99b3b47b0ecf8b2922be.CountRequestBuilder
Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows\microsoft.graph.count()
func (*RowsRequestBuilder) CreateGetRequestInformation ¶
func (m *RowsRequestBuilder) CreateGetRequestInformation(options *RowsRequestBuilderGetOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*RowsRequestBuilder) CreatePostRequestInformation ¶
func (m *RowsRequestBuilder) CreatePostRequestInformation(options *RowsRequestBuilderPostOptions) (*ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestInformation, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*RowsRequestBuilder) Get ¶
func (m *RowsRequestBuilder) Get(options *RowsRequestBuilderGetOptions) (*RowsResponse, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
func (*RowsRequestBuilder) ItemAtWithIndex ¶
func (m *RowsRequestBuilder) ItemAtWithIndex(index *int32) *i4dc8755710d719d95f4394ad3d766a3b2e88e20bbffceeb451852323c0f146ba.ItemAtWithIndexRequestBuilder
Builds and executes requests for operations under \workbooks\{driveItem-id}\workbook\tables\{workbookTable-id}\rows\microsoft.graph.itemAt(index={index}) Parameters:
- index : Usage: index={index}
func (*RowsRequestBuilder) Post ¶
func (m *RowsRequestBuilder) Post(options *RowsRequestBuilderPostOptions) (*i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow, error)
Represents a collection of all the rows in the table. Read-only. Parameters:
- options : Options for the request
type RowsRequestBuilderGetOptions ¶
type RowsRequestBuilderGetOptions struct {
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Request query parameters
Q *RowsRequestBuilderGetQueryParameters
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Get
type RowsRequestBuilderGetQueryParameters ¶
type RowsRequestBuilderGetQueryParameters struct {
ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.QueryParametersBase
// Include count of items
Count *bool
// Expand related entities
Expand []string
// Filter items by property values
Filter *string
// Order items by property values
Orderby []string
// Search items by search phrases
Search *string
// Select properties to be returned
Select_escaped []string
// Skip the first n items
Skip *int32
// Show only the first n items
Top *int32
}
Represents a collection of all the rows in the table. Read-only.
type RowsRequestBuilderPostOptions ¶
type RowsRequestBuilderPostOptions struct {
//
Body *i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow
// Request headers
H map[string]string
// Request options
O []ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.RequestOption
// Response handler to use in place of the default response handling provided by the core service
ResponseHandler ida96af0f171bb75f894a4013a6b3146a4397c58f11adb81a2b7cbea9314783a9.ResponseHandler
}
Options for Post
type RowsResponse ¶
type RowsResponse struct {
// contains filtered or unexported fields
}
func NewRowsResponse ¶
func NewRowsResponse() *RowsResponse
Instantiates a new rowsResponse and sets the default values.
func (*RowsResponse) GetAdditionalData ¶
func (m *RowsResponse) GetAdditionalData() map[string]interface{}
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (*RowsResponse) GetFieldDeserializers ¶
func (m *RowsResponse) GetFieldDeserializers() map[string]func(interface{}, i04eb5309aeaafadd28374d79c8471df9b267510b4dc2e3144c378c50f6fd7b55.ParseNode) error
The deserialization information for the current model
func (*RowsResponse) GetNextLink ¶
func (m *RowsResponse) GetNextLink() *string
Gets the nextLink property value.
func (*RowsResponse) GetValue ¶
func (m *RowsResponse) GetValue() []i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow
Gets the value property value.
func (*RowsResponse) IsNil ¶
func (m *RowsResponse) IsNil() bool
func (*RowsResponse) Serialize ¶
func (m *RowsResponse) Serialize(writer i04eb5309aeaafadd28374d79c8471df9b267510b4dc2e3144c378c50f6fd7b55.SerializationWriter) error
Serializes information the current object Parameters:
- writer : Serialization writer to use to serialize this model
func (*RowsResponse) SetAdditionalData ¶
func (m *RowsResponse) SetAdditionalData(value map[string]interface{})
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. Parameters:
- value : Value to set for the AdditionalData property.
func (*RowsResponse) SetNextLink ¶
func (m *RowsResponse) SetNextLink(value *string)
Sets the nextLink property value. Parameters:
- value : Value to set for the nextLink property.
func (*RowsResponse) SetValue ¶
func (m *RowsResponse) SetValue(value []i4a838ef194e4c99e9f2c63ba10dab9cb120a89367c1d4ab0daa63bb424e20d87.WorkbookTableRow)
Sets the value property value. Parameters:
- value : Value to set for the value property.